import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import Sco

import "./widgets"

Pane {
    id: root
    property real panelHeight: Style.parameter("geometry.topPanel.height")
    implicitHeight: panelHeight + topPadding + bottomPadding
    topPadding: Style.parameter("geometry.topPanel.topPadding", 30)
    rightPadding: Style.parameter("geometry.topPanel.rightPadding", 40)
    bottomPadding: Style.parameter("geometry.topPanel.bottomPadding", 40)
    leftPadding: Style.parameter("geometry.topPanel.leftPadding", 40)

    property color backgroundColor
    property alias appLogo: appLogo

    signal logo

    RowLayout {
        anchors.fill: parent
        spacing: 20

        ActionButton {
            id: appLogo
            Style.class: "logo"

            contentItem: SvgImage { source: Style.parameter("icon.topPanel.logo") }
            background: null

            onClicked: () => root.logo()
        }

        Space { width: 1 }

        ActionButton {
            id: lockButton
            Style.class: "lock"

            visible: Sco.showLock

            Layout.preferredHeight: panelHeight
            topPadding: panelHeight * 0.3
            bottomPadding: topPadding

            Layout.preferredWidth: panelHeight * 1.25
            leftPadding: panelHeight * 1.25 * 0.3
            rightPadding: leftPadding

            contentItem: SvgImage { source: Style.parameter("icon.topPanel.lock") }

            action: "AUTH_LOCK"
        }

        Space {
            Layout.fillWidth: true
        }

        SLabel {
            id: dateTimeLabel
            Style.class: "mainWindowDateTime"

            text: ""
            Timer {
                id: dateTimeTimer
                interval: 1000
                repeat: true
                running: true
                triggeredOnStart: true
                onTriggered: () => dateTimeLabel.text = new Date().toLocaleString("dd.MM.yyyy hh:mm")
            }
        }

        SLabel {
            Style.class: "mainWindowCashCodeLabel"
            visible: Sco.cashCode.length !== 0
            Tr {
                code: "mainWindowCashCodeLabel"
                args: [Sco.cashCode]
            }
        }

        ActionButton {
            id: help
            Style.class: "help"
            visible: Sco.showHelp
            icon: Style.parameter("icon.topPanel.help")
            Tr { code: "mainWindowHelp" }

            action: "SCO_HELP"
            leftPadding: 30
            rightPadding: 30
            Layout.preferredHeight: panelHeight
        }

        LanguageCombobox {
            LanguageModel { id: langs }
            model: langs
            visible: Sco.customerMode && langs.count > 1
            backgroundColor: root.backgroundColor
            Layout.preferredWidth: 194
            Layout.preferredHeight: panelHeight
        }

        Control {
            leftPadding: 20
            rightPadding: 20
            visible: Sco.showAttendPanel

            contentItem: Row {
                spacing: 10

                SvgImage {
                    source: Style.parameter("icon.topPanel.attendantMode")
                    anchors.verticalCenter: parent.verticalCenter
                }

                SLabel {
                    Style.class: "mainWindowAttendantMode"
                    Tr { code: "mainWindowAttendantMode" }
                    anchors.verticalCenter: parent.verticalCenter
                }
            }

            background: StrokedBorder {
                radius: 16
                strokeColor: Style.color("grayBorder")
                strokeWidth: 2
                dashPattern: [3, 4]
            }

            Layout.preferredHeight: panelHeight
        }
    }

    background: Rectangle { color: root.backgroundColor }
}
