import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n

import "../widgets"
import "../core"

ModalForm {
    id: root
    Style.class: "addBagForm"

    implicitWidth: Math.max(Style.parameter("geometry.addBagForm.implicitWidth", 735),
                            content.implicitWidth + leftPadding + rightPadding)
    implicitHeight: content.implicitHeight + topPadding + bottomPadding

    ColumnLayout {
        id: content
        objectName: "mainLayout"
        anchors.left: parent.left
        anchors.right: parent.right
        spacing: 80
        SLabel {
            Layout.fillWidth: true
            Style.class: "addBagTitle"
            Tr { code: "addBagTitle" }
            horizontalAlignment: Text.AlignHCenter
        }
        Item {
            id: bags
            objectName: "bags"
            Layout.preferredWidth: itemWidth * model.columns + spacing * (model.columns - 1)
            Layout.preferredHeight: {
                if (itemHeightForRow === undefined)
                    return 0
                let itemsHeight = 0
                for (let i = 0; i < itemHeightForRow.length; ++i)
                    itemsHeight += itemHeightForRow[i]
                return itemsHeight + spacing * (model.rows - 1)
            }
            Layout.alignment: Qt.AlignHCenter
            property BagsInfoModel model: BagsInfoModel {}
            property var itemHeightForRow
            property real itemWidth: 300
            property real spacing: 20
            property var bagsAdded

            Repeater {
                model: bags.model

                Item {
                    width: bags.itemWidth * model.rowSpan + bags.spacingCorrection(model.row)
                    height: bags.itemHeightForRow ? bags.itemHeightForRow[model.row] : 0
                    x: bags.getX(model.row, model.column, model.rowSpan)
                    y: bags.getY(model.row)

                    ColumnLayout {
                        id: itemContent
                        Layout.alignment: Qt.AlignVCenter
                        anchors.fill: parent
                        spacing: Style.parameter("geometry.addBag.bagDelegate.infoLayoutSpacing", 20)
                        onImplicitHeightChanged: {
                            bags.initItemHeights()
                            let newList = bags.itemHeightForRow
                            if (implicitHeight > bags.itemHeightForRow[model.row])
                                newList[model.row] = implicitHeight
                            bags.itemHeightForRow = newList
                        }
                        Item {
                            Layout.alignment: Qt.AlignTop
                            height: model.iconHeight
                            Layout.fillWidth: true
                            SvgImage {
                                anchors.fill: parent
                                source: Style.parameter(model.icon)
                            }
                        }
                        SLabel {
                            Layout.preferredWidth: bags.itemWidth
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "addBagItemName"
                            Tr { code: model.name }
                            horizontalAlignment: Text.AlignHCenter
                        }
                        SLabel {
                            Layout.preferredWidth: bags.itemWidth
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "addBagItemInfo"
                            Tr {
                                property bool withDef: model.defCount > 0
                                code: withDef ? "addBagMsgWithCount" : "addBagMsg"
                                args: withDef ? [ model.price, model.defCount ] : [ model.price ]
                            }
                            horizontalAlignment: Text.AlignHCenter
                        }
                        RowLayout {
                            Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                            Layout.topMargin: Style.parameter("geometry.addBag.bagDelegate.buttonsTopMargin", 40)
                            spacing: Style.parameter("geometry.addBag.bagDelegate.buttonsSpacing", 20)
                            ActionButton {
                                Style.class: "addBagMinus"
                                Layout.preferredWidth: Style.parameter("geometry.addBag.bagDelegate.buttonsWidth", 80)
                                Layout.preferredHeight: Style.parameter("geometry.addBag.bagDelegate.buttonsHeight", 80)
                                enabled: input.value > 0
                                iconAntialiasing: false
                                icon: enabled ? Style.parameter("icon.addBagFrom.minus")
                                              : Style.parameter("icon.addBagFrom.minus_disable")
                                onClicked: input.value--
                            }
                            SGroupBox {
                                Style.class: "addBagInputField"
                                Layout.preferredWidth: Style.parameter("geometry.addBag.bagDelegate.inputFieldWidth", 100)
                                Layout.preferredHeight: Style.parameter("geometry.addBag.bagDelegate.inputFieldHeight", 80)
                                STextEdit {
                                    anchors.centerIn: parent
                                    id: input
                                    property int value: 0
                                    enabled: false
                                    Style.class: "addBagInputField"
                                    text: (value + model.defCount)
                                    onValueChanged: bags.updateBagsAdded(index, value)
                                    Connections {
                                        target: bags
                                        function onBagsAddedChanged() {
                                            if (bags.bagsAdded && bags.bagsAdded[index])
                                                input.value = bags.bagsAdded[index]
                                        }
                                    }
                                }
                            }
                            ActionButton {
                                Style.class: "addBagPlus"
                                Layout.preferredWidth: Style.parameter("geometry.addBag.bagDelegate.buttonsWidth", 80)
                                Layout.preferredHeight: Style.parameter("geometry.addBag.bagDelegate.buttonsHeight", 80)
                                iconAntialiasing: false
                                icon: Style.parameter("icon.addBagFrom.plus")
                                onClicked: input.value++
                            }
                        }
                    }
                }
            }
            // Определить относительные координаты элемента по оси X
            function getX(row, column, span) {
                return (itemWidth * span + spacingCorrection(row) + spacing) * column
            }
            // Определить относительные координаты элемента по оси Y
            function getY(row) { return row ? (itemHeightForRow[row - 1] + spacing) * row : 0 }
            // Корректировка для ширины и X координаты на случай несовпадения количества столбцов в строках
            function spacingCorrection(row) {
                let cols = model.columnsForRow(row)
                return (model.columns - cols) * spacing / cols
            }
            // Инициализировать список высот для элементов
            function initItemHeights() {
                if (itemHeightForRow !== undefined)
                    return
                let newList = []
                for (let i = 0; i < model.rows; ++i)
                    newList.push(0)
                itemHeightForRow = newList
            }
            // Обновить количество добавляемых пакетов
            function updateBagsAdded(index, value) {
                let newMap = bagsAdded ? bagsAdded : {}
                if (newMap[index] === value)
                    return
                newMap[index] = value
                bagsAdded = newMap
            }
        }
        GridLayout {
            objectName: "controlButtonsLayout"
            Layout.fillWidth: true
            property bool vertical: true
            flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
            layoutDirection: vertical ? Qt.LeftToRight : Qt.RightToLeft
            rowSpacing: 20
            columnSpacing: 20

            ActionButton {
                Style.class: "addBagOk"
                objectName: "okButton"
                implicitWidth: 1
                Layout.fillWidth: true
                Layout.preferredHeight: 110
                Tr { code: "addBagConfirmOk" }
                enabled: {
                    if (bags.bagsAdded === undefined)
                        return false
                    for (let key in bags.bagsAdded)
                        if (bags.bagsAdded[key] > 0)
                            return true
                    return false
                }
                onClicked: {
                    Check.updateBagsInfos(bags.bagsAdded)
                    removeContext()
                }
            }
            ActionButton {
                Style.class: "addBagCancel"
                objectName: "cancelButton"
                implicitWidth: 1
                Layout.fillWidth: true
                Layout.preferredHeight: 110
                icon: Style.parameter("icon.addBagFrom.cancel")
                Tr { code: "addBagConfirmCancel" }
                onClicked: removeContext()
            }
        }
    }
}
