import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import Dialog
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "closedForm"

    contentItem: ColumnLayout {
        objectName: "mainLayout"
        spacing: 40

        SGroupBox {
            id: mainBox
            Layout.fillHeight: true
            Layout.fillWidth: true
            padding: 0

            ColumnLayout {
                objectName: "contentLayout"
                anchors.horizontalCenter: parent.horizontalCenter
                y: 280

                SLabel {
                    Style.class: "closedThanks"
                    Layout.alignment: Qt.AlignHCenter
                    Layout.maximumWidth: mainBox.width
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap

                    Tr { code: "closedThanks" }
                }
                Space { objectName: "titleSpacer"; Layout.preferredHeight: 100 }
                SLabel {
                    Style.class: "closedHintGoods"
                    Layout.alignment: Qt.AlignHCenter
                    Layout.maximumWidth: mainBox.width
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap
                    Tr {
                        code: {
                            switch (Check.closedHint) {
                            case CheckTypes.ClosedHint.goods:
                                return Check.receipt == CheckTypes.Receipt.paper ? "closedHintReceipt" : "closedHintGoods"
                            case CheckTypes.ClosedHint.receipt:
                                return Check.receiptType == DialogTypes.CustomerAddressType.Sms ? "closedHintReceiptSendOnPhoneNumber"
                                                                                                : "closedHintReceiptSendOnEmail"
                            default: return ""
                            }
                        }
                    }
                }
                Space { objectName: "hintSpacer"; Layout.preferredHeight: 300 }
                Loader {
                    id: hintLoader
                    Layout.alignment: Qt.AlignHCenter
                    source: {
                        switch (Check.closedHint) {
                        case CheckTypes.ClosedHint.goods: return Style.ui("check/GoodsHint")
                        case CheckTypes.ClosedHint.receipt:
                            return Check.receiptType == DialogTypes.CustomerAddressType.Sms ? Style.ui("check/PhoneNumberReceiptHint")
                                                                                            : Style.ui("check/EmailReceiptHint")
                        default: return ""
                        }
                    }
                }
            }
        }

        ActionButton {
            visible: !Check.goodsOnScale
            Layout.preferredHeight: 110
            Layout.fillWidth: true
            objectName: "closedCompletePurchase"
            Style.class: "closedCompletePurchase"

            Tr { code: "closedCompletePurchase" }

            action: "CHECK_WELCOME"
            onClicked: () => PluginManager.internalAsync("CORE_HINT", { name: "Closed" })
            ActionButtonTimer {
                visible: Check.closedHintTimer.active && Check.closedHint == CheckTypes.ClosedHint.goods
                secondsLeft: Check.closedHintTimer.interval / 1000;
                onVisibleChanged: { secondsLeft = Check.closedHintTimer.interval / 1000; }
                label.font: parent.font
            }
        }
    }
}
