import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "discInfoForm"

    focusPolicy: Qt.ClickFocus

    ColumnLayout {
        anchors.fill: parent
        Layout.fillWidth: true
        spacing: 20

        SGroupBox {
            Layout.fillHeight: true
            Layout.fillWidth: true

            GridLayout {
                objectName: "mainLayout"
                anchors.fill: parent
                rowSpacing: 20
                columnSpacing: 20
                columns: 1

                ColumnLayout {
                    objectName: "positionsLayout"
                    Layout.leftMargin: 90
                    Layout.rightMargin: Layout.leftMargin
                    Layout.topMargin: 55
                    Layout.bottomMargin: 35
                    Layout.fillWidth: true
                    Layout.fillHeight: true
                    spacing: 30

                    SLabel {
                        objectName: "discInfoTitle"
                        Style.class: "discInfoTitle"
                        horizontalAlignment: Text.AlignHCenter

                        Tr { code: "discInfoTitle" }

                        Layout.preferredHeight: contentHeight
                        Layout.preferredWidth: contentWidth
                        Layout.alignment: Qt.AlignHCenter
                    }

                    LoyaltyButtons {
                        id: loyaltyInfo
                        objectName: "loyaltyButtons"
                        enabled: !Check.hasLoyaltyCard
                        inputCouponTrCode: "discInfoInputCoupon"
                        scanCardTrCode: "discInfoScanLoyaltyCard"
                        cardBalanceTrCode: "discInfoCardBalance"

                        inputCouponButton {
                            Style.class: "discInfoInputCoupon"
                            visible: false
                        }
                        animationStyleSection: ".discInfo"
                        inputCardButton.Style.class: "discInfoInputCard"
                        model.onLayoutChanged: () => discountLayout.update()
                    }

                    DashLineSeparator {
                        Layout.fillWidth: true; Layout.alignment: Qt.AlignTop;
                        dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                    }

                    SGroupBox {
                        id: mainBox
                        objectName: "mainBox"
                        leftPadding: 0
                        rightPadding: leftPadding
                        topPadding: 30
                        bottomPadding: 0
                        Layout.fillWidth: true
                        Layout.fillHeight: true
                        Layout.topMargin: -parent.spacing / 2

                        contentItem: Item {
                            anchors.fill: parent

                            ColumnLayout {
                                anchors.fill: parent
                                spacing: 10

                                PositionList {
                                    id: positionList
                                    objectName: "positionList"
                                    Layout.fillHeight: true
                                    Layout.fillWidth: true

                                    CheckModel { id: checkModel; onChanged: () => model.invalidate() }
                                    model: FilterModel {
                                        id: model
                                        sourceModel: checkModel
                                        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position || pos.type == CheckTypes.ItemType.Coupon
                                    }
                                    backgroundColor: mainBox.background.color

                                    property real delegateHeight: Style.parameter("geometry.discInfoForm.positionList.positionDelegate.height", 100)
                                    property real delegatePositionSumWidth: updateWidth()

                                    FontMetrics {
                                        id: fm
                                        Style.type: "Label"
                                        Style.class: "discInfoPositionSumNoDisc"
                                        font: Style.text.font
                                    }

                                    // Расчет ширины блока суммы позиции на основании размера шрифта
                                    function updateWidth() {
                                        let maxSum = Math.max(...Check.positions.map(x => x.sum.value + x.discount.value))
                                        let money = Money.create(maxSum)
                                        return fm.boundingRect(Money.format(money, false)).width
                                    }

                                    delegate: ColumnLayout {
                                        width: positionList.width
                                        height: positionList.delegateHeight
                                        opacity: positionList.getItemOpasity(this)

                                        RowLayout {
                                            Layout.fillWidth: true; Layout.alignment: Qt.AlignVCenter
                                            Layout.topMargin: Style.parameter("geometry.discInfoForm.positionList.positionDelegate.topMargin", 0)
                                            Space { width: Style.parameter("geometry.discInfoForm.positionList.positionDelegate.leftSpace", 10) }
                                            SLabel {
                                                Layout.fillWidth: true
                                                Style.class: "discInfoPositionName"
                                                text: model.name

                                                Tr {
                                                    code: { return "couponName" }
                                                    args: [name]
                                                    enabled: type === CheckTypes.ItemType.Coupon
                                                }

                                                elide: Text.ElideRight
                                                wrapMode: Text.WordWrap
                                                maximumLineCount: 2
                                            }
                                            Space { width: 20 }
                                            SLabel {
                                                leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                                                visible: model.type === CheckTypes.ItemType.Position
                                                Style.class: "discInfoPositionQuantity"
                                                text: model.quantity ? "x" + model.quantity.str : ""
                                            }
                                            Space { width: 20 }
                                            Control {
                                                visible: model.type === CheckTypes.ItemType.Position
                                                implicitWidth: positionList.delegatePositionSumWidth

                                                contentItem: ColumnLayout {
                                                    anchors.fill: parent
                                                    spacing: Style.parameter("geometry.discInfoForm.positionList.positionDelegate.sumLayoutSpacing", 5)

                                                    SMoney {
                                                        id: positionSum
                                                        Style.class: "discInfoPositionSumNoDisc"
                                                        money: model.sumNoDisc
                                                        color: styleColor
                                                        backgroundColor: Style.color("background")
                                                        Layout.alignment: Qt.AlignRight
                                                    }
                                                    SMoney {
                                                        Style.class: "discInfoPositionDiscSum"
                                                        prefix: "-"
                                                        money: (model.disc)
                                                        visible: model.disc ? !model.disc.zero : false
                                                        color: styleColor
                                                        backgroundColor: Style.color("background")
                                                        Layout.alignment: Qt.AlignRight
                                                    }
                                                }
                                            }
                                            Space { width: Style.parameter("geometry.discInfoForm.positionList.positionDelegate.rightSpace", 30) }
                                        }
                                        DashLineSeparator {
                                            Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                                            dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                                        }
                                    }
                                }

                                DashLineSeparator {
                                    Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                                    dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                                }

                                ColumnLayout {
                                    id: discountLayout
                                    objectName: "discountLayout"
                                    property ListModel discInfo: ListModel { id: discountInfoModel }

                                    FilterModel {
                                        id: cards
                                        sourceModel: CheckModel { id: cardsModel; onChanged: () => cards.invalidate() }
                                        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Card && pos.hasBalance

                                        onLayoutChanged: () => discountLayout.update()
                                    }

                                    Layout.fillWidth: true
                                    Component.onCompleted: () => update()
                                    function update() {
                                        discountInfoModel.clear()
                                        const cardIndex = cards.index(0, 0)
                                        if (cards.count > 0 && cardIndex.valid) {
                                            discInfo.append({ labelTr: "discInfoBalance", labelStyle: "discInfoBalance",
                                                              value: cards.data(cardIndex, CheckModel.Balance).value, valueStyle: "discInfoBalanceValue"})
                                            discInfo.append({ labelTr: "discInfoEarn", labelStyle: "discInfoEarn",
                                                              value: cards.data(cardIndex, CheckModel.Earn).value, valueStyle: "discInfoEarnValue"})
                                            discInfo.append({ labelTr: "discInfoSpend", labelStyle: "discInfoSpend",
                                                              value: cards.data(cardIndex, CheckModel.CanSpend).value, valueStyle: "discInfoSpendValue"})
                                        }
                                        discInfo.append({ labelTr: "discInfoDisc", labelStyle: "discInfoDiscountSum",
                                                          value: Check.discount.value, valueStyle: "discInfoDiscountSumValue" })
                                    }

                                    Repeater {
                                        id: discountInfo
                                        model: discountInfoModel
                                        delegate: RowLayout {
                                            spacing: 40

                                            SLabel {
                                                Style.class: model.labelStyle
                                                Tr { code: model.labelTr }
                                                Layout.fillWidth: true
                                            }
                                            SMoney {
                                                Style.class: model.valueStyle
                                                money: Money.create(model.value)
                                                color: styleColor
                                                backgroundColor: Style.color("background")
                                            }

                                            Layout.fillWidth: true
                                            Layout.preferredHeight: Style.parameter("geometry.discInfoForm.discountInfo.positionDelegate.height", 60)
                                            width: discountInfo.width
                                            Layout.leftMargin: Style.parameter("geometry.discInfoForm.discountInfo.positionDelegate.leftMargin", 20)
                                        }
                                    }
                                }

                                ColumnLayout {
                                    id: totalLayout
                                    objectName: "totalLayout"

                                    DashLineSeparator {
                                        Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom
                                        dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                                    }

                                    RowLayout {
                                        objectName: "totalLabelLayout"
                                        spacing: 40

                                        SLabel {
                                            Style.class: "discInfoDue"
                                            Tr { code: "discInfoDue" }
                                            Layout.fillWidth: true
                                        }
                                        SMoney {
                                            Style.class: "discInfoDueValue"
                                            money: Check.total
                                            color: styleColor
                                            backgroundColor: Style.color("background")
                                        }

                                        Layout.fillWidth: true
                                        Layout.preferredHeight: 60
                                        Layout.leftMargin: 20
                                        Layout.bottomMargin: 20
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }

        ColumnLayout {
            objectName: "additionalInfoLayout"
            Layout.fillWidth: true
            Layout.fillHeight: true

            ActionButton {
                id: continueButton
                objectName: "continueButton"
                Style.class: "discInfoClose"

                Tr { code: "discInfoClose" }
                onClicked: () => removeContext()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
                Layout.topMargin: 20
            }
        }
    }
}
