import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

BaseForm {
    id: root
    Style.class: "formingForm"

    Context.context {
        inputSources: InputSources.All | InputSources.Rfid
        logoActionInfo: true
    }

    focusPolicy: Qt.ClickFocus

    CheckModel {
        id: checkModel
        onChanged: () => positions.invalidate()
    }
    FilterModel {
        id: positions
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
    }

    ColumnLayout {
        anchors.fill: parent
        spacing: 20

        LoyaltyButtons {
            objectName: "loyaltyButtons"
            scanCardTrCode: "formingScanLoyaltyCard"
            cardBalanceTrCode: "formingCardBalance"
            inputCouponTrCode: "formingInputCoupon"

            inputCouponButton {
                Style.class: "formingInputCoupon"
                visible: Config.getBool("Scong:showInputCouponInForming")
            }

            animationStyleSection: ".forming"
            inputCardButton.Style.class: "formingInputCard"
        }

        SGroupBox {
            id: pcBox
            padding: 30

            property bool showPickList: mainBox.checkItems.count === 0
            state: showPickList ? "onlyPickList" : "onlyButton"
            states: [
                State {
                    name: "onlyPickList";
                    PropertyChanges { target: showPickListButton; opacity: 0 }
                    PropertyChanges { target: pickListItem.navigationBox; visible: true; opacity: 1 }
                },
                State {
                    name: "onlyButton";
                    PropertyChanges { target: pickListItem.navigationBox; opacity: 0 }
                    PropertyChanges { target: showPickListButton; visible: true; opacity: 1 }
                }
            ]
            transitions: [
                Transition { from: "onlyPickList"; to: "onlyButton"
                    SequentialAnimation {
                        NumberAnimation {
                            target: pickListItem.navigationBox; property: "opacity"; easing.type: Easing.InOutQuad;
                            duration: Style.animationDuration("transition.forming.pickList", 200)
                        }
                        PropertyAction { target: pickListItem.navigationBox; property: "visible"; value: false }
                        NumberAnimation {
                            target: showPickListButton; property: "opacity"; easing.type: Easing.InOutQuad;
                            duration: Style.animationDuration("transition.forming.pickList", 300)
                        }
                    }
                },
                Transition { from: "onlyButton"; to: "onlyPickList"
                    SequentialAnimation {
                        NumberAnimation {
                            target: showPickListButton; property: "opacity"; easing.type: Easing.InOutQuad;
                            duration: Style.animationDuration("transition.forming.pickList", 250)
                        }
                        PropertyAction { target: showPickListButton; property: "visible"; value: false }
                        NumberAnimation {
                            target: pickListItem.navigationBox; property: "opacity"; easing.type: Easing.InOutQuad;
                            duration: Style.animationDuration("transition.forming.pickList", 250)
                        }
                    }
                }
            ]

            onShowPickListChanged: { pickListItem.log?.info(`${showPickList ? "Отображение" : "Закрытие" } мини-каталога товаров`) }

            contentItem: PickList {
                id: pickListItem
                searchItem: RowLayout {
                    anchors.fill: parent
                    spacing: 15

                    SGroupBox {
                        Style.class: "pickListSearch"
                        Layout.fillWidth: true
                        Layout.fillHeight: true

                        ActionButton {
                            anchors.fill: parent
                            Style.class: "pickListSearch"
                            icon: Style.parameter("icon.pickList.search")
                            Tr { code: "pickListSearchHint" }

                            action: "PICKLIST_SHOW"
                        }
                    }

                    ActionButton {
                        Style.class: "formingPickListDetect"
                        Tr { code: "pickListDetectItem" }
                        enabled: pcBox.showPickList
                        visible: PluginManager.hasHandler(action)
                        action: "GOODSDETECTOR_DETECT"
                        Layout.preferredWidth: parent.width / 3
                        Layout.fillHeight: true
                    }
                }

                onSelected: (index) => {
                    root.async("PICKLIST_SELECT", {
                        item: PL.PickList.pageModel.modelItem(index)
                    })
                }

                Component.onDestruction: { log?.info("Закрытие мини-каталога товаров") }
            }

            Behavior on Layout.preferredHeight {
                NumberAnimation { easing.type: Easing.InOutQuad;
                    duration: Style.animationDuration("transition.forming.pickList", 500)
                }
            }

            ActionButton {
                id: showPickListButton
                Style.class: "formingPickList"
                anchors.fill: parent
                enabled: !parent.showPickList
                Tr { code: "formingPickList" }

                action: "PICKLIST_SHOW"
            }

            Layout.fillWidth: true
            Layout.preferredHeight: showPickList ? 650 : 90
        }

        BasketBox {
            id: mainBox
            objectName: "mainBox"
            Layout.fillWidth: true
            Layout.fillHeight: true
        }

        AgeVerifyNotificationBox { }

        RowLayout {
            spacing: 40

            SLabel {
                Style.class: "formingTotal"
                Tr { code: "formingTotal" }
                Layout.fillWidth: true
            }

            SMoney {
                Style.class: "formingTotalSumNoDisc"
                visible: Check.total !== Check.totalNoDisc
                discount: true
                money: Check.totalNoDisc
                color: Style.color("grayDark")
                backgroundColor: Style.color("background")
            }

            SMoney {
                Style.class: "formingTotalSum"
                money: Check.total
            }

            Layout.fillWidth: true
            Layout.preferredHeight: 60
            Layout.bottomMargin: 20
        }

        ActionButton {
            id: subtotalButton
            property bool back: Check.status === CheckTypes.Status.None
            Style.class: !back ? "formingSubtotal" : "formingBack"
            enabled: back || (positions.count > 0)
            icon: !back ? Style.parameter("icon.forming.subtotal") : Style.parameter("icon.forming.back")
            iconSize: 32
            Tr { code: !subtotalButton.back ? "formingSubtotal" : "formingBack" }
            action: !back ? "CHECK_SUBTOTAL" : "CHECK_BACKTOWELCOME"
            Layout.fillWidth: true
            Layout.preferredHeight: 110
        }

        RowLayout {
            spacing: 20

            ActionButton {
                Style.class: "flat"
                Tr { code: "formingChangeNextQuantity" }
                icon: Style.parameter("icon.forming.inputQuantity")
                action: "CHECK_CHANGENEXTQUANTITY"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            ActionButton {
                Style.class: "flat"
                Tr { code: "formingInput" }
                icon: Style.parameter("icon.forming.input")
                action: "CHECK_MANUALINPUT"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            Layout.fillWidth: true
            Layout.maximumHeight: 90
        }
    }

    pushEnter: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 0
                duration: Style.animationDuration("transition.forming", 300)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 1
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.forming", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "opacity"; to: 1; duration: 0 }
    }
}
