import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n

import "../core"
import "../widgets"

ModalForm {
    id: root
    Style.class: "inputCardForm"

    Context.inputSources: InputSources.Msr | InputSources.Scanner

    Component.onCompleted: () => {
        const methods = Config.getList("Check:cardInputMethods", ["read"])
                // Удаляем дубликаты
                .filter((item, pos, self) => self.indexOf(item) === pos)

        for (const m of methods) {
            switch (m) {
            case "phone":
                model.append({ button: "inputCardByPhone", cardInputMethod: CheckTypes.CardInputMethod.Phone, manual: true })
                break
            case "number":
                model.append({ button: "inputCardByNumber", cardInputMethod: CheckTypes.CardInputMethod.Number, manual: true })
                break
            case "read":
                model.append({ button: "inputCardByReading", cardInputMethod: CheckTypes.CardInputMethod.Number, manual: false,
                        hint: "inputCardByReadingHint", hintStyle: "hint.inputCard" })
                break
            case "paymentCode":
                model.append({ button: "inputCardByPaymentCode", cardInputMethod: CheckTypes.CardInputMethod.PaymentCode, manual: true })
                break
            }
        }

        if (model.methods.count == 0)
            model.append({ button: "inputCardByReading", cardInputMethod: CheckTypes.CardInputMethod.Number,
                    hint: "inputCardByReadingHint", manual: false })
    }

    contentItem: InputMethodList {
        id: model
        objectName: "inputMethodList"

        title { objectName: "title"; Style.class: "inputCardTitle" }
        titleTr: Tr.create("inputCardTitle")
        message { objectName: "message"; Style.class: "inputCardMessage" }
        messageTr: Tr.create("inputCardMessage")
        hint { Style.class: "inputCardHint" }
        controls.cancelButton { Style.class: "inputCardCancel" }
        inputMethodClass: "inputCardMethod"

        accept: function() {
            if (!model.controls.inputField.acceptableInput)
                return

            if (model.currentMethod.cardInputMethod == CheckTypes.CardInputMethod.Phone)
                addCardAction.number = model.controls.inputField.text.replace(/\(|\)|-/g, '')
            else
                addCardAction.number = model.controls.inputField.text
            addCardAction.cardInputMethod = model.currentMethod.cardInputMethod
            addCardAction.exec()
        }

        controls.useDigits: true
        controls.okButtonTr: Tr.create("inputCardApply")
        controls.cancelButtonTr: Tr.create("inputCardCancel")
        controls.inputFieldClass: "inputCardInputField"
        controls.cancelButton.icon: Context.suggest ? "" : Style.parameter("icon.input.cancel")

        // При передаче параметра cardInputMethod через QVariantMap в PluginManager.async происходят проблемы
        Action {
            id: addCardAction
            command: "CHECK_ADDCARD"

            property string number
            property int source: EInput.Keyboard
            property int cardInputMethod
        }

        okButtonConnections.enabled: false
        controls.okButton {
            Style.class: "inputCardConfirm"
            onClicked: () => accept()
        }
    }
}
