import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n

import "../core"
import "../widgets"

ModalForm {
    id: root
    Style.class: "inputCouponForm"

    Context.inputSources: InputSources.Msr | InputSources.Scanner

    Component.onCompleted: () => {
        const methods = Config.getList("Check:couponInputMethods", [""])
                // Удаляем дубликаты
                .filter((item, pos, self) => self.indexOf(item) === pos)

        for (const m of methods) {
            switch (m) {
            case "number":
                model.append({ button: "inputCouponByNumber", cardInputMethod: CheckTypes.CardInputMethod.Number, manual: true })
                break
            case "scan":
                model.append({ button: "inputCouponByScan", cardInputMethod: CheckTypes.CardInputMethod.Number,
                        hint: "inputCouponByScanningHint", manual: false, hintStyle: "hint.inputCoupon" })
                break
            }
        }

        if (model.methods.count == 0)
            model.append({ button: "inputCouponByScan", cardInputMethod: CheckTypes.CardInputMethod.Number,
                    hint: "inputCouponByScanningHint", manual: false, hintStyle: "hint.inputCoupon" })
    }

    contentItem: InputMethodList {
        id: model
        objectName: "inputMethodList"

        title { Style.class: "inputCouponTitle" }
        titleTr: Tr.create("inputCouponTitle")
        message { Style.class: "inputCouponMessage" }
        messageTr: Tr.create("inputCouponMessage")
        hint { Style.class: "inputCouponHint"}
        controls.cancelButton { Style.class: "inputCouponCancel" }
        inputMethodClass: "inputCouponMethod"

        accept: function() {
            if (!model.controls.inputField.acceptableInput)
                return

            addCouponAction.data = model.controls.inputField.text
            addCouponAction.rawData = model.controls.inputField.text
            addCouponAction.exec()
        }

        controls.useDigits: true
        controls.okButtonTr: Tr.create("inputCouponApply")
        controls.cancelButtonTr: Tr.create("inputCouponCancel")
        controls.inputFieldClass: "inputCouponInputField"
        controls.cancelButton.icon: Context.suggest ? "" : Style.parameter("icon.input.cancel")

        Action {
            id: addCouponAction
            command: "CORE_INPUT"

            property string data
            property string rawData
            property int dataSource: EInput.Keyboard
            property int inputType: EInput.Text
        }

        okButtonConnections.enabled: false
        controls.okButton {
            Style.class: "inputCouponConfirm"
            onClicked: () => accept()
        }
    }
}
