import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "paymentForm"
    focusPolicy: Qt.ClickFocus

    Context.logoActionInfo: true

    property bool partialPayment: partialPayment.visible && partialPayment.checked

    contentItem: GridLayout {
        objectName: "mainLayout"
        rowSpacing: 40
        columnSpacing: 40
        columns: 1
        SGroupBox {
            id: infoBlock
            objectName: "infoBlock"
            Layout.fillWidth: true
            Layout.fillHeight: true
            ColumnLayout {
                objectName: "dataLayout"
                y: 100
                anchors.horizontalCenter: parent.horizontalCenter
                spacing: 0
                SLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "paymentTitle"
                    Tr { code: "paymentTitle" }
                }
                Space { objectName: "titleSpacer"; Layout.preferredHeight: 30 }
                SLabel {
                    objectName: "paymentHintLabel"
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "paymentHint"
                    horizontalAlignment: Label.AlignHCenter
                    Tr { code: Check.due.zero ? "paymentHintPaid" : "paymentHint" }
                    wrapMode: Label.Wrap
                }
                Space { objectName: "hintSpacer"; Layout.preferredHeight: 60 }
                SvgImage {
                    Layout.alignment: Qt.AlignHCenter
                    source: bonusBlock.visible && couponBlock.visible
                            ? Style.parameter("image.paymentCheckLong")
                            : Style.parameter("image.paymentCheck")
                    ColumnLayout {
                        objectName: "checkInfoLayout"
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.leftMargin: 50
                        anchors.rightMargin: 50
                        spacing: 20
                        SLabel {
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "paymentDue"
                            Tr { code: "paymentDue" }
                        }
                        SMoney {
                            Layout.alignment: Qt.AlignHCenter
                            visible: !Check.discount.zero
                            Style.class: "paymentTotalNoDiscValue"
                            money: Check.totalNoDisc
                            discount: true
                            color: styleColor
                            backgroundColor: infoBlock.Style.background.color
                        }
                        SMoney {
                            Layout.alignment: Qt.AlignHCenter
                            Style.class: "paymentDueValue"
                            money: Check.due
                            color: styleColor
                        }
                        RowLayout {
                            Layout.alignment: Qt.AlignHCenter
                            SLabel {
                                Style.class: "paymentPaid"
                                Tr { code: "paymentPaid" }
                            }
                            SMoney {
                                Style.class: Check.paid.zero ? "paymentPaidZero" : "paymentPaidValue"
                                money: Check.paid
                                color: styleColor
                            }
                        }
                        ColumnLayout {
                            id: bonusBlock
                            visible: !Check.earn.zero
                            Layout.alignment: Qt.AlignHCenter
                            spacing: parent.spacing
                            DashLineSeparator {
                                Layout.fillWidth: true
                                Layout.preferredHeight: strokeWidth
                                strokeWidth: 1
                                dashPattern: [ 10, 10 ]
                                color: Style.color("grayBorder")
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarn"
                                Tr { code: "paymentEarn" }
                            }
                            SMoney {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarnValue"
                                money: Check.earn
                                color: styleColor
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentEarnHint"
                                Tr { code: "paymentEarnHint" }
                            }
                        }
                        ColumnLayout {
                            id: couponBlock
                            visible: Check.coupon
                            Layout.alignment: Qt.AlignHCenter
                            spacing: parent.spacing
                            DashLineSeparator {
                                Layout.fillWidth: true
                                Layout.preferredHeight: strokeWidth
                                strokeWidth: 1
                                dashPattern: [ 10, 10 ]
                                color: Style.color("grayBorder")
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponTitle"
                                Tr { code: "paymentCouponTitle" }
                            }
                            SLabel {
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponName"
                                text: Check.coupon ? Check.coupon.name : ""
                            }
                            SLabel {
                                property string campaign: Check.coupon ? Check.coupon.campaignName : ""
                                visible: campaign.length > 0
                                Layout.alignment: Qt.AlignHCenter
                                Style.class: "paymentCouponMessage"
                                text: campaign
                            }
                        }
                        Space { objectName: "checkEndSpacer"; height: 50 }
                    }
                }
            }
            RowLayout {
                objectName: "paymentPartialLayout"
                x: (parent.width - implicitWidth) / 2
                y: parent.height - 20 - implicitHeight
                visible: Config.getBool("Check:editPaySum", false) && !Check.due.zero
                spacing: 24
                SSwitch {
                    objectName: "paymentPartialSwitch"
                    flow: Qt.RightToLeft
                    id: partialPayment
                    Style.class: "paymentPartialSwitch"
                    Tr { code: "paymentPayInParts" }
                    property bool defalutChecked: Config.getBool("Check:editPaySumByDefault", true)
                    checked: defalutChecked
                    onCheckedChanged: {
                        if (checked && !defalutChecked)
                            PluginManager.async("CORE_HINT", { name: "PayInParts" })
                    }
                    onVisibleChanged: if (!visible && !defalutChecked) checked = false
                }
                ActionButton {
                    objectName: "paymentPartialHelp"
                    Layout.preferredWidth: 40
                    Layout.preferredHeight: 40
                    Layout.alignment: Qt.AlignVCenter
                    Style.class: "explanation"
                    action: "CHECK_PARTIALPAYMENTHELP"
                    text: "?"
                }
            }
        }
        ColumnLayout {
            objectName: "buttonsLayout"
            spacing: 40
            Item {
                id: paymentButtons
                objectName: "paymentButtons"
                visible: !Check.due.zero
                Layout.fillWidth: true
                property PaymentMethodsModel paymentModel: PaymentMethodsModel{}
                property real spacing: 20
                property real buttonHeight: 110
                property int rows: paymentModel.buttonRows()
                Layout.preferredHeight: buttonHeight * rows + spacing * (rows - 1)
                Repeater {
                    model: paymentButtons.paymentModel
                    delegate: ActionButton {
                        enabled: model.available
                        width: paymentButtons.buttonWidth(row)
                        height: paymentButtons.buttonHeight
                        x: paymentButtons.getX(column, width)
                        y: paymentButtons.getY(row)
                        Style.class: model.style
                        icon: model.icon
                        iconSize: !model.name ? 0 : Style.parameter("geometry.actionButton.iconSize", 32)
                        Tr { code: name }

                        action: Action {
                            command: "CHECK_ADDPAYMENT"
                            property int paymentType: model.type
                            property string paymentCode: model.code
                            property int idleTimeout: model.idleTimeout
                            property bool partialPayment: root.partialPayment
                            property bool callAttendant: model.callAttendant
                            property string paymentName: model.paymentName
                        }
                    }
                }
                function getX(column, buttonWidth) {
                    return (buttonWidth + spacing) * column
                }
                function getY(row) {
                    return (buttonHeight + spacing) * row
                }
                function buttonWidth(row) {
                    const count = paymentModel.buttonRowCount(row)
                    return width / count - spacing * (count - 1) / count
                }
            }

            ActionButton {
                objectName: "paymentClose"
                visible: Check.due.zero
                Layout.fillWidth: true
                Layout.preferredHeight: 110
                action: "CHECK_CLOSE"
                Tr { code: "paymentClose" }
            }

            ActionButton {
                objectName: "paymentBackToForming"
                Layout.alignment: Qt.AlignVCenter
                Layout.fillWidth: true
                Layout.preferredHeight: 110
                Style.class: "paymentBackToForming"
                action: "CHECK_BACKTOFORMING"
                Tr { code: "paymentBack" }
                enabled: !Check.due.zero || Config.getBool("Check:backToFormingPaid")
                icon: Style.parameter("icon.payment.backToForming")
            }
        }
    }
}
