import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "welcomeForm"

    Context.context {
        inputSources: InputSources.All | InputSources.Rfid
        topPanelColor: Style.color("welcomeBackground")
        logoActionInfo: true
    }

    ColumnLayout {
        objectName: "mainLayout"
        anchors.fill: parent
        anchors.topMargin: 200
        anchors.bottomMargin: background.bottomPadding + 240
        spacing: 80

        ColumnLayout {
            objectName: "titleLayout"
            Layout.alignment: Qt.AlignHCenter
            spacing: 80

            SLabel {
                objectName: "welcomeTitle"
                Style.class: "welcomeTitle"
                Tr { code: "welcomeTitle" }
                Layout.alignment: Qt.AlignHCenter
            }

            SLabel {
                objectName: "welcomeScanBarcode"
                Style.class: "welcomeScanBarcode"
                Tr { code: "welcomeScanBarcode" }
                horizontalAlignment: Qt.AlignHCenter
                wrapMode: Text.WordWrap
                Layout.maximumWidth: 800
                Layout.alignment: Qt.AlignHCenter
            }
        }

        SLabel {
            objectName: "welcomeOrPressButton"
            Style.class: "welcomeOrPressButton"
            Tr { code: "welcomeOrPressButton" }
            horizontalAlignment: Qt.AlignHCenter
            Layout.alignment: Qt.AlignHCenter
        }

        ColumnLayout {
            objectName: "buttonsLayout"
            spacing: 45
            Layout.alignment: Qt.AlignHCenter
            Layout.maximumWidth: 480
            Layout.minimumHeight: Math.max(spacing, (buttonHeight + spacing) * children.length) - spacing
            property real buttonHeight: 128

            ActionButton {
                objectName: "welcomeStart"
                Style.class: "welcomeStart"
                Tr { code: "welcomeStart" }
                action: "CHECK_START"
                Layout.alignment: Qt.AlignHCenter | Qt.AlignTop
                Layout.preferredHeight: parent.buttonHeight
                Layout.fillWidth: true
            }

            ActionButton {
                objectName: "welcomePriceChecker"
                Style.class: "welcomePriceChecker"
                Tr { code: "welcomePriceChecker" }
                action: "PRICECHECKER_SHOW"
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredHeight: parent.buttonHeight
                Layout.fillWidth: true
            }
        }

        ColumnLayout {
            objectName: "paymentMethodsLayout"
            spacing: 50
            Layout.alignment: Qt.AlignHCenter

            SLabel {
                objectName: "welcomePaymentListTitle"
                Style.class: "welcomePaymentListTitle"
                Tr { code: "welcomePayments" }
                horizontalAlignment: Qt.AlignHCenter
                Layout.alignment: Qt.AlignHCenter
            }

            Speener {
                id: paymentMethodsList
                objectName: "paymentMethodsList"
                Layout.alignment: Qt.AlignHCenter
                Layout.preferredHeight: 50
                Layout.preferredWidth: 950
                interactive: count > pathItemCount
                pathItemCount: 3
                spacing: 80
                contentItemWidth: 200
                currentIndex: count > (pathItemCount - 1) ? 1 : 0

                property real preferredHighlight: count != 2 ? 0.5 : (2/7)
                preferredHighlightBegin: preferredHighlight
                preferredHighlightEnd: preferredHighlight

                model: PaymentMethodsModel { withDisabled: false }

                IdleMonitor {
                    id: autoSpeenTimer
                    property real configSeconds: Style.parameter("welcomePaymentMethodsListAutoscrollSeconds", 2)
                    property real configManualSeconds: Style.parameter("welcomePaymentMethodsListAutoscrollManualSeconds", 5)
                    seconds: configSeconds
                    enabled: Context.onTop && paymentMethodsList.count > paymentMethodsList.pathItemCount
                    onTimeout: () => {
                        seconds = configSeconds
                        paymentMethodsList.currentIndex += 1
                        interrupt()
                    }
                }

                onFlickingChanged: () => {
                    autoSpeenTimer.seconds = autoSpeenTimer.configManualSeconds
                    autoSpeenTimer.interrupt()
                }

                Behavior on offset { NumberAnimation { duration: Style.animationDuration("welcome.autoscroll", 500) } }

                delegate: RowLayout {
                    objectName: "paymentMethodListDelegate"
                    visible: PathView.onPath
                    spacing: 20

                    /**
                    * _x:   Значение где находится текущий элемент.
                    *       Экспериментальным путем было выяснено, что отображаются элементы с 0.5 по 3.5
                    *
                    * _opacity: Ненормализованное значение прозрачности
                    *           Таблица некоторых значений в зависимости от _x:
                    *          | _x  | _opacity |
                    *          |   0 |   -1     |
                    *          | 0.5 |    0     |
                    *          |   1 |    1     |
                    *          |   2 |    3     |
                    *          |   3 |    1     |
                    *          | 3.5 |    0     |
                    *          |   4 |    -1    |
                    */
                    property real _x: (model.index + PathView.view.offset + 2) % PathView.view.count
                    property real _opacity: _x > 2 ? 7 - 2 * _x : 2 * _x - 1
                    opacity: paymentMethodsList.count > 3 ? Math.max(0, Math.min(_opacity, 1)) : 1

                    SvgImage {
                        objectName: "welcomePaymentIcon"
                        Style.class: "welcomePaymentIcon"
                        Layout.preferredWidth: Style.parameter("geometry.welcome.paymentList.iconSize", 50)
                        Layout.preferredHeight: Style.parameter("geometry.welcome.paymentList.iconSize", 50)
                        source: model.welcomeIcon
                    }

                    SLabel {
                        objectName: "welcomePaymentName"
                        Style.class: "welcomePaymentName"
                        Tr { code: model.welcomeName }
                        Layout.preferredWidth: Style.parameter("geometry.welcome.paymentList.nameWidth", 130)
                        wrapMode: Text.WordWrap
                        horizontalAlignment: Qt.AlignLeft
                        verticalAlignment: Qt.AlignVCenter
                    }
                }
            }
        }
    }

    property real bgMultiplier: 1

    background: SmileBackground {
        multiplier: root.bgMultiplier
        color: Style.color("welcomeBackground")
        footerColor: Style.color("welcomeFooterBackground")
        footerImage: Style.parameter("image.welcomeFooter")
        shadowColor: Style.color("welcomeShadow")
    }

    pushExit: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 1.0; to: 0.97
                easing.type: Easing.OutQuad
                duration: Style.animationDuration("transition.welcome", 200)
            }
            NumberAnimation {
                target: root; property: "bgMultiplier"
                from: 0.97; to: 2
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.welcome", 600)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 1; to: 0
                easing.type: Easing.OutCubic
                duration: Style.animationDuration("transition.welcome", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "bgMultiplier"; to: 1; duration: 0 }
        NumberAnimation { target: root; property:      "opacity"; to: 1; duration: 0 }
    }
}
