import QtQml.Base
import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Dialog

import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "askToContinueForm"

    property var action: DialogState.actions[Context.id.value]

    function accept() {
        action.result = true
        removeContext()
    }

    function reject() {
        action.result = false
        removeContext()
    }

    Keys.onEnterPressed: () => root.accept()
    Keys.onReturnPressed: () => root.accept()
    Keys.onEscapePressed: () => root.reject()

    contentItem: ColumnLayout {
        objectName: "mainLayout"
        spacing: 40

        SGroupBox {
            Layout.fillWidth: true
            Layout.fillHeight: true
            padding: 0

            ColumnLayout {
                objectName: "contentLayout"
                spacing: 0
                anchors.horizontalCenter: parent.horizontalCenter
                y: 280

                SLabel {
                    objectName: "titleLabel"
                    Style.class: "askToContinueTitle"
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap
                    Tr { tr: action.title }

                    Layout.fillWidth: true
                }

                Space { objectName: "titleSpacer"; Layout.preferredHeight: 40 }

                SLabel {
                    objectName: "messageLabel"
                    Style.class: "askToContinueMessage"
                    horizontalAlignment: SLabel.AlignHCenter
                    wrapMode: SLabel.WordWrap
                    Tr { tr: action.message }

                    Layout.fillWidth: true
                }

                Space { objectName: "imageSpacer"; Layout.preferredHeight: 200 }

                SvgImage {
                    objectName: "image"
                    Layout.alignment: Qt.AlignHCenter
                    source: action.image
                }
            }
        }

        RowLayout {
            objectName: "buttonsLayout"
            spacing: 40

            ActionButton {
                objectName: "cancelButton"
                Style.class: "askToContinueCancel"
                Tr { tr: action.cancelButton }

                implicitWidth: 1

                onClicked: () => root.reject()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }

            ActionButton {
                objectName: "applyButton"
                Style.class: "askToContinueApply"
                Tr { tr: action.okButton }

                implicitWidth: 1

                onClicked: () => root.accept()

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }
        }
    }
}
