import QtQml.Base
import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Sco
import Dialog

import "../core"
import "../widgets"

ModalForm {
    id: root
    Style.class: "inputTextForm"

    RegularExpressionValidator { id: regexpValidator; regularExpression: new RegExp(root.action.regexp) }

    property var action: DialogState.actions[Context.id.value]
    Context.context.inputSources: InputSources.inputSources(action.inputSources)
    onActivated: () => controls.inputField.forceActiveFocus()

    ColumnLayout {
        objectName: "mainLayout"
        spacing: 40
        Layout.fillWidth: true
        anchors.fill: parent

        SLabel {
            id: title
            Style.class: "inputTextTitle"

            Tr { tr: root.action.title }

            Layout.fillWidth: true
            wrapMode: SLabel.WordWrap
            horizontalAlignment: SLabel.AlignHCenter
        }

        SLabel {
            id: message
            Style.class: "inputTextMessage"

            Tr { tr: root.action.message }

            Layout.fillWidth: true
            wrapMode: SLabel.WordWrap
            horizontalAlignment: SLabel.AlignHCenter
        }

        InputControls {
            id: controls
            objectName: "inputControls"

            useDigits: true
            okButtonTr: root.action.okButton?.empty ? Tr.create("inputTextApply") : root.action.okButton
            cancelButtonTr: root.action.cancelButton?.empty ? Tr.create("inputTextCancel") : root.action.cancelButton
            inputFieldClass: "inputTextInputField"

            inputField {
                echoMode: root.action.hideInput ? TextInput.Password : TextInput.Normal
                validator: root.action.regexp.length > 0 ? regexpValidator : null
                horizontalAlignment: Qt.AlignHCenter
            }

            okButton {
                Style.class: "inputTextConfirm"
                enabled: root.action.regexp.length > 0 ? controls.inputField.acceptableInput : controls.inputField.text.length > 0

                onClicked: () => {
                    if (!controls.inputField.acceptableInput)
                        return

                    root.action.text = controls.inputField.text
                    removeContext()
                }
            }
            cancelButton {
                Style.class: "inputTextCancel"

                onClicked: () => {
                    root.action.text = ""
                    removeContext()
                }
            }
        }
    }
}
