import QtQml.Base
import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Sco
import Dialog

import "../core"
import "../widgets"

/**
 * Диалог ввода суммы оплаты баллами
 */
ModalForm {
    id: root

    property var action: DialogState.actions[Context.id.value]

    onActivated: () => {
        controls.inputField.forceActiveFocus()
        if (controls.inputField.text)
            controls.inputField.selectAll()
    }

    Keys.onEnterPressed: () => accept()
    Keys.onReturnPressed: () => accept()
    Keys.onEscapePressed: () => reject()

    contentItem: ColumnLayout {
        objectName: "mainLayout"
        spacing: 40
        SLabel {
            id: title
            objectName: "titleLabel"
            Style.class: "loyaltyInputTitle"
            horizontalAlignment: SLabel.AlignHCenter
            wrapMode: SLabel.WordWrap

            Tr { tr: action.title }

            Layout.fillWidth: true
        }

        RowLayout {
            objectName: "infoLayout"
            spacing: 20
            SGroupBox {
                objectName: "balanceGroup"
                implicitWidth: 1
                Layout.fillWidth: true
                Style.class: "loyaltyInputSum"
                padding: 40
                leftPadding: 43
                rightPadding: 43
                contentItem: ColumnLayout {
                    objectName: "balanceLayout"
                    spacing: 20
                    SLabel {
                        Style.class: "loyaltyInputSumTitle"
                        Tr { tr: action.balanceTitle }
                    }
                    SLabel {
                        Style.class: "loyaltyInputBalance"
                        text: action.balance.str
                    }
                }
            }
            SGroupBox {
                objectName: "canSpendGroup"
                implicitWidth: 1
                Layout.fillWidth: true
                Style.class: "loyaltyInputSum"
                padding: 40
                leftPadding: 43
                rightPadding: 43
                contentItem: ColumnLayout {
                    objectName: "canSpendLayout"
                    spacing: 20
                    SLabel {
                        Style.class: "loyaltyInputSumTitle"
                        Tr { tr: action.canSpendTitle }
                    }
                    SLabel {
                        Style.class: "loyaltyInputCanSpend"
                        text: action.canSpend.str
                    }
                }
            }
        }

        InputControls {
            id: controls
            useDigits: true
            okButtonTr: action.okButton
            cancelButtonTr: action.cancelButton
            inputField {
                id: inputField
                validator: DoubleValidator {
                    id: dv
                    notation: DoubleValidator.StandardNotation
                    decimals: 2
                    top: parseFloat(action.canSpend.str)
                    bottom: 0.0
                }

                Component.onCompleted: () => {
                    if (action.text.length > 0) {
                        inputField.text = action.text
                        inputField.selectAll()
                    }
                }
            }
            okButton {
                onClicked: () => accept()
            }
            cancelButton {
                onClicked: () => reject()
            }
        }
    }

    function accept() {
        action.text = inputField.text
        removeContext()
    }

    function reject() {
        action.canceled = true
        removeContext()
    }
}
