import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Dialog
import I18n

import "../widgets"
import "../core"

ModalForm {
    id: root
    Style.class: "multiChoiceForm"

    property var action: DialogState.actions[Context.id.value]

    ColumnLayout {
        id: layout
        objectName: "mainLayout"
        anchors.left: parent.left
        anchors.right: parent.right
        spacing: 40

        SLabel {
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignHCenter
            wrapMode: SLabel.WordWrap
            Style.class: "multiChoiceTitle"
            Tr { tr: root.action.title }
        }

        SLabel {
            Layout.fillWidth: true
            horizontalAlignment: Text.AlignHCenter
            wrapMode: SLabel.WordWrap
            Style.class: "multiChoiceMessage"
            Tr { tr: root.action.message }
        }

        Space { height: 20; visible: action.image.exists }
        Item {
            height: root.action.imageHeight
            Layout.fillWidth: true
            visible: action.image.exists
            SvgImage {
                anchors.fill: parent
                source: action.image
            }
        }

        ColumnLayout {
            Layout.fillWidth: true
            spacing: 20

            Repeater {
                model: Math.ceil(root.action.choices.length / 3)
                RowLayout {
                    id: rowLayout
                    Layout.fillWidth: true
                    spacing: 10
                    property int currentRow: index
                    Repeater {
                        model: {
                            const itemsLeft = root.action.choices.length - 3 * currentRow
                            return itemsLeft > 3 ? 3 : itemsLeft
                        }
                        Item {
                            Layout.preferredHeight: Style.parameter("geometry.multiChoice.choiceDelegate.buttonHeight", 100)
                            Layout.fillWidth: true
                            ActionButton {
                                anchors.fill: parent
                                Style.class: "multiChoiceOption"
                                Tr { tr: root.action.choices.get(currentRow * 3 + index) }
                                onClicked: {
                                    root.action.result = rowLayout.currentRow * 3 + index
                                    removeContext()
                                }
                            }
                        }
                    }
                }
            }
        }

        ActionButton {
            objectName: "cancelButton"
            Layout.preferredHeight: 100
            Layout.fillWidth: true
            visible: root.action.showCancel
            Style.class: "multiChoiceCancel"
            Tr { tr: root.action.cancelButton }
            onClicked: {
                root.action.result = -1
                removeContext()
            }
        }
    }
}
