import QtQuick
import QtQuick.Layouts

import Core
import I18n
import Input

import "../core"
import "../widgets"

ModalForm {
    id: root
    Style.class: "weightForm"

    property var action: Input.weighingAction

    Keys.onEnterPressed: () => okButton.clicked()
    Keys.onReturnPressed: () => okButton.clicked()
    Keys.onEscapePressed: () => cancelButton.clicked()

    ColumnLayout {
        objectName: "mainLayout"
        anchors.fill: parent
        spacing: 40

        SLabel {
            id: title
            Style.class: "weightTitle"
            Tr { code: action.title.empty ? "weightTitle" : action.title }

            Layout.alignment: Qt.AlignHCenter
        }

        SLabel {
            id: message
            Style.class: "weightHint"
            Tr { code: "weightHint" }

            Layout.alignment: Qt.AlignHCenter
        }

        GoodsCard {
            hidePrice: Context.goodsDetect
            name: action.name
            barcode: action.barcode
            image: action.image.valid ? action.image : "image.weight.placeholder"
            price: action.price.zero ? null : action.price

            labelName: "weightName"
            labelBarcode: "weightBarcode"
            moneyPrice: "weightPrice"
        }

        SLabel {
            id: weight
            Style.class: "weightState"
            Tr { enabled: Input.weightError.empty; code: "weightState"; args: [ Input.weight.str ] }
            Tr { enabled: !Input.weightError.empty; tr: Input.weightError }
            Layout.preferredWidth: parent.width
            wrapMode: Text.WordWrap
            Layout.alignment: Qt.AlignHCenter
            horizontalAlignment: Text.AlignHCenter
        }

        ColumnLayout {
            objectName: "controlButtonsLayout"
            spacing: 15
            Layout.topMargin: 20

            ActionButton {
                id: okButton
                objectName: "okButton"
                Style.class: "weightOk"
                visible: Input.confirmWeighing
                enabled: Input.weight.isGreater(Context.ignoreLowWeight) && Input.weightError.empty
                Tr { code: "weightConfirm" }
                ActionButtonTimer {
                    id: timer
                    seconds: Input.confirmWeighingTimeout / 1000
                    icon: Style.parameter("icon.weight.timer")
                    label.color: Style.parameter("color.weightTimerLabelColor")
                    onTimeout: () => okButton.clicked()
                }
                onEnabledChanged: () => {
                    if (enabled && visible)
                        timer.run()
                    else
                        timer.cancel()
                }

                onClicked: () => { if (enabled) root.removeContext() }

                Layout.fillWidth: true
                Layout.preferredHeight: 105
            }

            ActionButton {
                id: cancelButton
                objectName: "cancelButton"
                Style.class: "weightCancel"
                Tr { code: "weightCancel" }
                icon: Style.parameter("icon.weight.cancel")
                onClicked: () => {
                    Input.weight = Fract.fromGrams(0)
                    root.removeContext()
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 105
            }

            Layout.fillWidth: true
        }
    }
}
