import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

ModalForm {
    id: root
    Style.class: "pickListForm"

    anchors.fill: parent
    implicitWidth: content.implicitWidth
    implicitHeight: content.implicitHeight

    allowFloatKeyboard: true

    Component.onDestruction: { pickList.log?.info("Закрытие каталога товаров") }

    // Сигнал закрытия клавиатуры. Прокидывается в Application.qml
    signal hideKeyboard()

    Control {
        id: content
        objectName: "mainBox"
        property int picklistWidth: Style.parameter("geometry.pickList.modalForm.width", 1080)
        property int picklistHeight: Style.parameter("geometry.pickList.modalForm.height", 1920)
        property int gridRowsCount: Style.parameter("geometry.pickList.modalForm.rowsCount", 6)
        property int gridColumnsCount: Style.parameter("geometry.pickList.modalForm.columnsCount", 4)

        implicitWidth: picklistWidth - Layout.leftMargin - Layout.rightMargin
        implicitHeight: picklistHeight - Layout.topMargin - Layout.bottomMargin

        Layout.margins: 36
        Layout.bottomMargin: 84
        Layout.topMargin: 80
        anchors.fill: parent

        contentItem: ColumnLayout {
            spacing: 36

            SGroupBox {
                padding: 5

                contentItem: PickList {
                    id: pickList
                    objectName: "pickList"
                    grid: Qt.size(content.gridColumnsCount, content.gridRowsCount)

                    onHideKeyboard: root.hideKeyboard()

                    Action {
                        id: action
                        command: "PICKLIST_SELECT"
                        property var item
                    }

                    onSelected: (index) => {
                        action.item = PL.PickList.pageModel.modelItem(index)
                        action.exec()
                    }
                }

                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            ActionButton {
                id: closeModalPickList
                objectName: "closeButton"
                Style.class: "outlined"
                visible: PL.PickList.canCloseDialog

                icon: Style.parameter("icon.pickList.close")
                Tr { code: "pickListClose" }

                onClicked: () => {
                    pickList.clearFilter()
                    PL.PickList.pageModel.reset()
                    removeContext()
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 110
            }
        }
    }
}
