import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.VirtualKeyboard
import QtQuick.VirtualKeyboard.Styles
import QtQuick.VirtualKeyboard.Settings

import Core

KeyboardStyle {
    id: currentStyle

    property string layoutType: "main"

    property string defaultStyleName: {
        if (layoutType === "digits")
            return "digitsKeyboardKey"
        return "keyboardKey"
    }

    property string grayStyleName: {
        if (layoutType === "digits")
            return "digitsKeyboardKey"
        return "grayKeyboardKey"
    }

    keyboardDesignWidth: 930
    keyboardDesignHeight: 460

    keyPanel: TextKey { Style.class: ["@", ".", "-", "_"].indexOf(control.displayText) >= 0 ? grayStyleName
                                                                                     : defaultStyleName }
    backspaceKeyPanel: IconKey {
        Style.class: grayStyleName
        icon: {
            if (control.pressed)
                return Style.parameter("icon.keyboard.backspacePressed")
            return Style.parameter("icon.keyboard.backspaceDefault")
        }
        iconWidth: Style.parameter("geometry.keyboard.backspace.iconWidth", 50)
    }
    languageKeyPanel: TextKey { Style.class: grayStyleName }
    shiftKeyPanel: IconKey {
        Style.class: grayStyleName
        iconWidth: Style.parameter("geometry.keyboard.shift.iconWidth", 27)
        icon: {
            if (control.pressed)
                return Style.parameter("icon.keyboard.shiftCapsLock")
            if (InputContext.capsLockActive)
                return Style.parameter("icon.keyboard.shiftCapsLock")
            if (InputContext.shiftActive)
                return Style.parameter("icon.keyboard.shiftActive")
            return Style.parameter("icon.keyboard.shiftDefault")
        }
    }
    spaceKeyPanel: IconKey {
        Style.class: defaultStyleName
        icon: {
            if (control.pressed)
                return Style.parameter("icon.keyboard.spacebarPressed")
            return Style.parameter("icon.keyboard.spacebarDefault")
        }
        iconWidth: Style.parameter("geometry.keyboard.space.iconWidth", 24)
    }

    alternateKeysListItemWidth: 100
    alternateKeysListItemHeight: 100
    alternateKeysListDelegate: Rectangle {
        width: alternateKeysListItemWidth
        height: alternateKeysListItemHeight
        Text {
            id: alternateKeysListDelegate
            text: model.text
            anchors.centerIn: parent
            Style.type: "Label"
            Style.class: ListView.isCurrentItem ? "keyboardAlternateKeyHighlight"
                                                : "keyboardAlternateKeyDefault"
            color: Style.text.color
            font: Style.text.font
        }

        color: alternateKeysListDelegate.Style.background.color
        radius: alternateKeysListDelegate.Style.border.radius
        border.color: alternateKeysListDelegate.Style.border.color
        border.width: alternateKeysListBackground.Style.border.width
    }

    /// Убираем все не используемое
    hideKeyPanel: null
    symbolKeyPanel: null
    modeKeyPanel: null
    enterKeyPanel: null
    alternateKeysListHighlight: null
    keyboardBackground: null
    handwritingKeyPanel: null
    characterPreviewMargin: 0
    characterPreviewDelegate: null
    selectionListHeight: 0
    selectionListDelegate: null
    selectionListBackground: null
    selectionListAdd: null
    selectionListRemove: null
    navigationHighlight: null
    traceInputKeyPanelDelegate: null
    traceCanvasDelegate: null
    popupListBackground: null
    popupListAdd: null
    popupListRemove: null
    selectionHandle: null
    fullScreenInputContainerBackground: null
    fullScreenInputBackground: null
    fullScreenInputMargins: 0
    fullScreenInputPadding: 0
    fullScreenInputCursor: null
    fullScreenInputFont.pixelSize: 0

    /// Язык переключаем нажатием, без списка
    languagePopupListEnabled: false
    languageListDelegate: null
    languageListBackground: null
    languageListAdd: null
    languageListRemove: null
}
