import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core
import Check
import I18n
import Input
import WeightControl

import "../check"
import "../core"
import "../widgets"

BaseForm {
    id: root
    Style.class: "weightControlErrorForm"
    focusPolicy: Qt.ClickFocus

    Context.logoActionInfo: "WEIGHTCONTROL_ERRORAUTH"

    property int error: WeightControl.error
    property bool heft: error === WeightControlTypes.NotAdded && WeightControl.errorCanBeCanceled

    ColumnLayout {
        objectName: "mainLayout"
        Layout.fillWidth: true
        anchors.fill: parent
        spacing: 20

        SGroupBox {
            objectName: "mainBox"
            Layout.fillWidth: true
            Layout.fillHeight: true
            topPadding: 175

            contentItem: GridLayout {
                objectName: "errorInfoLayout"
                Layout.fillWidth: true
                anchors.centerIn: parent
                columnSpacing: 50
                rowSpacing: 50
                columns: 1

                ColumnLayout {
                    objectName: "errorHintLayout"
                    Layout.fillWidth: true
                    spacing: 50

                    SLabel {
                        objectName: "titleLabel"
                        Layout.alignment: Qt.AlignCenter
                        Layout.fillWidth: true
                        Layout.preferredWidth: parent.width
                        horizontalAlignment: Text.AlignHCenter
                        wrapMode: SLabel.WordWrap
                        Style.class: "weightControlErrorTitle"

                        Tr {
                            code: {
                                if (root.heft)
                                    return "wceHeftTitle"

                                switch(root.error) {
                                case WeightControlTypes.NotAdded: return "wceNotAddedTitle"
                                case WeightControlTypes.NotScanned: return "wceNotScannedTitle"
                                case WeightControlTypes.Overweight: return "wceOverweightTitle"
                                case WeightControlTypes.Removed: return "wceRemovedTitle"
                                case WeightControlTypes.RemovedHeft: return "wceRemovedHeftTitle"
                                case WeightControlTypes.NotStable: return "wceNotStableTitle"
                                case WeightControlTypes.WrongWeight: return "wceWrongWeightTitle"
                                case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseTitle"
                                case WeightControlTypes.NotScannedPay: return "wceNotScannedPayTitle"
                                default: return ""
                                }
                            }
                        }
                    }

                    SLabel {
                        objectName: "messageLabel"
                        Layout.alignment: Qt.AlignCenter
                        Layout.fillWidth: true
                        Layout.preferredWidth: parent.width
                        horizontalAlignment: Text.AlignHCenter
                        Style.class: "weightControlErrorHint"
                        wrapMode: SLabel.WordWrap

                        Tr {
                            code: {
                                if (root.heft)
                                    return WeightControl.weightItemHint.code

                                switch(root.error) {
                                case WeightControlTypes.NotAdded: return "wceNotAddedHint"
                                case WeightControlTypes.NotScanned: return "wceNotScannedHint"
                                case WeightControlTypes.Overweight: return "wceOverweightHint"
                                case WeightControlTypes.Removed: return "wceRemovedHint"
                                case WeightControlTypes.NotStable: return "wceNotStableHint"
                                case WeightControlTypes.WrongWeight: return "wceWrongWeightHint"
                                case WeightControlTypes.NotScannedAbuse: return "wceNotScannedAbuseHint"
                                case WeightControlTypes.NotScannedPay: return "wceNotScannedPayHint"
                                case WeightControlTypes.RemovedHeft: return "wceRemovedHeftHint"
                                default: return ""
                                }
                            }

                            args: {
                                if (root.heft)
                                    return [ WeightControl.weightItemName ]
                            }
                        }
                    }

                    Loader {
                        objectName: "weightHintLoader"
                        Layout.alignment: Qt.AlignCenter
                        Layout.topMargin: 200
                        property int weightItemWidth: 540
                        property int weightItemHeight: 540
                        property Component imageComponent: SvgImage {
                            property ImageData imageData: WeightControl.weightItemImage
                            source: imageData
                            width: parent.weightItemWidth
                            height: parent.weightItemHeight
                            implicitWidth: parent.weightItemHeight
                            implicitHeight: parent.weightItemHeight
                        }
                        sourceComponent: root.heft && WeightControl.weightItemImage.valid ? imageComponent : null
                        source: {
                            if (root.heft && WeightControl.weightItemImage.valid)
                                return ""

                            switch(root.error) {
                            case WeightControlTypes.NotStable: return Style.ui("weightcontrol/UnstableImage")
                            case WeightControlTypes.WrongWeight: return Style.ui("weightcontrol/WrongWeightImage")
                            case WeightControlTypes.Overweight:
                            case WeightControlTypes.NotScannedAbuse:
                            case WeightControlTypes.NotScannedPay:
                            case WeightControlTypes.NotScanned: return Style.ui("weightcontrol/RemovingImage")
                            case WeightControlTypes.NotAdded:
                            case WeightControlTypes.Removed:
                            case WeightControlTypes.RemovedHeft: return Style.ui("weightcontrol/AddingImage")
                            default: return ""
                            }
                        }
                    }

                    SLabel {
                        objectName: "heftWeightLabel"
                        Style.class: "weightControlHeftWeight"
                        Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                        Layout.fillWidth: true
                        horizontalAlignment: Text.AlignHCenter
                        visible: root.heft

                        Tr {
                            id: weightTextTr
                            code: "weightControlWeighingWeight"
                            args: {
                                const weightDifference = Fract.fromGrams(WeightControl.currentWeight.value - WeightControl.previousWeight.value)
                                const greaterZero = weightDifference.isGreaterOrEqual(Fract.zero)
                                return [greaterZero ? weightDifference.str : Fract.zero.str]
                            }
                        }
                    }
                }

                PositionList {
                    id: positionList
                    objectName: "positionList"
                    property real delegateHeight: 100
                    Layout.alignment: Qt.AlignCenter
                    Layout.minimumHeight: delegateHeight
                    Layout.fillHeight: true
                    Layout.preferredWidth: 840
                    Layout.topMargin: 20
                    visible: !root.heft && [ WeightControlTypes.WrongWeight, WeightControlTypes.NotAdded,
                        WeightControlTypes.NotScanned, WeightControlTypes.NotScannedPay,
                        WeightControlTypes.Removed, WeightControlTypes.NotScannedAbuse,
                        WeightControlTypes.RemovedHeft ].indexOf(root.error) >= 0
                    Component.onCompleted: scrollToEnd()
                    CheckModel {
                        id: checkModel
                        onChanged: () => { model.invalidate(); positionList.scrollToEnd(); }
                    }
                    model: FilterModel {
                        id: model
                        sourceModel: checkModel
                        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
                    }
                    delegate: ColumnLayout {
                        width: positionList.width
                        height: positionList.delegateHeight
                        DashLineSeparator {
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignTop; visible: !index
                            dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                        }
                        RowLayout {
                            Layout.topMargin: Style.parameter("geometry.weightControl.errorForm.positionList.positionDelegate.topMargin", 0)
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignVCenter
                            Space { width: 10 }
                            RowLayout {
                                Layout.alignment: Qt.AlignVCenter
                                spacing: Style.parameter("geometry.weightControl.errorForm.positionList.positionDelegate.spacing", 20)

                                SLabel {
                                    Layout.fillWidth: true
                                    Style.class: "weightControlPositionName"
                                    text: model.name
                                    elide: Text.ElideRight
                                }
                                SLabel {
                                    leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                                    Style.class: "weightControlPositionError"
                                    Tr { code: model.wcStatus }
                                    visible: text.length > 0
                                }
                                SLabel {
                                    leftPadding: 17; rightPadding: 17; topPadding: 6; bottomPadding: 6
                                    Style.class: "weightControlPositionQuantity"
                                    text: "x" + model.quantity.str
                                }
                            }
                            Space { width: Style.parameter("geometry.weightControl.errorForm.positionList.positionDelegate.rightSpace", 30) }
                        }
                        DashLineSeparator {
                            Layout.fillWidth: true; Layout.alignment: Qt.AlignBottom; Layout.bottomMargin: 1
                            dashPattern: [1, 0]; strokeWidth: 1; color: Style.color("graySoft")
                        }
                    }
                }
            }
        }

        Control {
            objectName: "controlButtons"
            visible: root.heft || root.error === WeightControlTypes.RemovedHeft
            contentItem: RowLayout {
                id: buttonsLayout
                objectName: "controlButtonsLayout"
                anchors {
                    right: parent.right
                    left: parent.left
                }

                readonly property int buttonsWidth: width / 2 - spacing / 2

                ActionButton {
                    id: cancelWeighting
                    Style.class: "weightControlHeftCancel"
                    Layout.minimumWidth: parent.buttonsWidth
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    action: "WEIGHTCONTROL_CANCELWEIGHING"
                    icon: Style.parameter("icon.weightControlHeft.cancel")
                    Tr { code: "weightControlErrorCancel" }
                }
                ActionButton {
                    id: confirmWeighting
                    Style.class: "weightControlHeftConfirm"
                    enabled: WeightControl.canConfirm && !WeightControl.weightsAreEqual && WeightControl.currentWeight.isGreater(WeightControl.previousWeight)
                    Layout.minimumWidth: 0
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    action: "WEIGHTCONTROL_CONFIRMWEIGHTING"
                    Tr { code: "weightControlErrorConfirmWeighing" }

                    ActionButtonTimer {
                        id: timer
                        seconds: Input.confirmWeighingTimeout / 1000
                        icon: Style.parameter("icon.weight.timer")
                        label.color: Style.parameter("color.weightTimerLabelColor")
                        onTimeout: () => confirmWeighting.clicked()
                    }

                    onEnabledChanged: () => {
                        if (enabled && visible)
                            timer.run()
                        else
                            timer.cancel()
                    }
                }

                Behavior on spacing {
                    NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.weightControl.weighing", 250) }
                }
            }

            state: WeightControl.confirmWeighing && root.error !== WeightControlTypes.RemovedHeft ? "cancelAndConfirm" : "cancel"
            states: [
                State {
                    name: "cancel";
                    PropertyChanges { target: cancelWeighting; Layout.preferredWidth: buttonsLayout.width }
                    PropertyChanges { target: confirmWeighting; opacity: 0; Layout.preferredWidth: 0 }
                    PropertyChanges { target: buttonsLayout; spacing: 0; }
                },
                State {
                    name: "cancelAndConfirm";
                    PropertyChanges { target: buttonsLayout; spacing: 20; }
                    PropertyChanges { target: cancelWeighting; Layout.preferredWidth: buttonsLayout.buttonsWidth }
                    PropertyChanges { target: confirmWeighting; opacity: 1; Layout.preferredWidth: buttonsLayout.buttonsWidth }
                }
            ]
            transitions: [
                Transition { from: "cancel"; to: "cancelAndConfirm"
                    NumberAnimation {
                        target: cancelWeighting; property: "Layout.preferredWidth"; easing.type: Easing.InOutQuad
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                    NumberAnimation {
                        target: confirmWeighting; properties: "Layout.preferredWidth,opacity"; easing.type: Easing.InOutQuad
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                },
                Transition { from: "cancelAndConfirm"; to: "cancel"
                    NumberAnimation {
                        target: cancelWeighting; property: "Layout.preferredWidth"; easing.type: Easing.InOutQuad;
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                    NumberAnimation {
                        target: confirmWeighting; property: "Layout.preferredWidth"; easing.type: Easing.InOutQuad;
                        duration: Style.animationDuration("transition.weightControl.weighing", 250)
                    }
                    NumberAnimation {
                        target: confirmWeighting; property: "opacity"; easing.type: Easing.InOutQuad;
                        duration: Style.animationDuration("transition.weightControl.weighing", 200)
                    }
                }
            ]

            Layout.fillWidth: true
            Layout.preferredHeight: 90
            Layout.maximumHeight: 90
        }
    }
}
