import QtQuick
import QtQuick.Controls

import Core

import "../widgets"

Page {
    leftPadding: 75
    rightPadding: 0
    topPadding: 0
    bottomPadding: 0
    width: scale.width + leftPadding
    height: scale.height
    background: null

    SvgImage {
        id: scale
        source: Style.parameter("image.weightControl.unstable.scales")
        SvgImage {
            id: hand
            x: -131
            property real baseVelocity: Style.animationVelocity("weightControl.unstable", 200)
            state: timer.currentState
            source: Style.parameter("image.weightControl.unstable.hand")
            states: [
                State { name: "start"; PropertyChanges { target: hand; y: 135; rotation: 0 }},
                State { name: "finish"; PropertyChanges { target: hand; y: 185; rotation: 15 }}
            ]
            transitions: Transition {
                SmoothedAnimation { properties: "y"; velocity: hand.baseVelocity }
                SmoothedAnimation { properties: "rotation"; velocity: hand.baseVelocity * 0.3 }
            }
        }
        Timer {
            id: timer
            property string currentState: "start"
            interval: Style.animationDuration("weightControl.unstable", 3000)
            running: true
            triggeredOnStart: true
            repeat: true
            onTriggered: {
                if (currentState == "start")
                    currentState = "finish"
                else
                    currentState = "start"
            }
        }
    }

    property var dashes: [
        {
            begX: 85 - leftPadding,
            begY: 510,
            endX: -25 - leftPadding,
            rotation: 5
        },
        {
            begX: 85 - leftPadding,
            begY: 520,
            endX: -30 - leftPadding,
            rotation: -15
        },
        {
            begX: 80 - leftPadding,
            begY: 525,
            endX: -5 - leftPadding,
            rotation: -40
        },
        {
            begX: width - 145 - leftPadding,
            begY: 510,
            endX: width - 40 - leftPadding,
            rotation: -5
        },
        {
            begX: width - 145 - leftPadding,
            begY: 520,
            endX: width - 35 - leftPadding,
            rotation: 15
        },
        {
            begX: width - 145 - leftPadding,
            begY: 525,
            endX: width - 55 - leftPadding,
            rotation: 40
        }
    ]
    function getEndY(model) {
        var lambdaX = model.endX - model.begX
        const toRad = deg => (deg * Math.PI) / 180.0
        return model.begY + (lambdaX * Math.sin(toRad(model.rotation))) / Math.sin(toRad(90 - model.rotation))
    }
    Repeater {
        z: parent.z - 1
        model: dashes
        Rectangle {
            id: dash
            property real endY: getEndY(modelData)
            property real lambdaX: Math.abs(modelData.endX - modelData.begX)
            property real lambdaY: Math.abs(endY - modelData.begY)
            color: Style.color("redSoft")
            width: 60
            height: 4
            radius: 4
            z: parent.z - 1
            rotation: modelData.rotation
            state: timer.currentState
            states: [
                State { name: "start"; PropertyChanges { target: dash; x: modelData.begX; y: modelData.begY } },
                State { name: "finish"; PropertyChanges { target: dash; x: modelData.endX; y: endY } }
            ]
            transitions: Transition {
                SmoothedAnimation {
                    properties: "x"
                    velocity: hand.baseVelocity * (dash.lambdaX / 50)
                }
                SmoothedAnimation {
                    properties: "y"
                    velocity: hand.baseVelocity * (dash.lambdaY / 50)
                }
            }
        }
    }
}
