import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core

/**
 * @brief Кнопка с действием
 *
 * @param action действие (может иметь тип Core::QmlAction* или строка)
 *
 * @signal clicked() сигнал нажатия
 */
Control {
    id: root
    Style.type: "ActionButton"

    property var action
    property string text
    property url icon
    property real iconSize: Style.parameter("geometry.actionButton.iconSize", 32)
    property alias iconFixedColor: buttonIcon.fixedColor
    property alias iconVisible: buttonIcon.visible
    property alias iconAntialiasing: buttonIcon.antialiasing
    property color color: Style.text.color
    property alias down: mouse.pressed
    property alias border: background.border

    visible: !root.action || PluginManager.hasHandler(root.action)
    font: Style.text.font

    signal clicked()

    contentItem: ColumnLayout {
        RowLayout {
            spacing: Style.parameter("geometry.actionButton.mainLayoutSpacing", 20)

            SvgImage {
                id: buttonIcon
                visible: root.icon.toString().length !== 0
                source: root.icon ? root.icon : null
                Layout.preferredWidth: root.iconSize
                Layout.preferredHeight: root.iconSize
                Layout.alignment: Qt.AlignCenter
            }

            SLabel {
                id: label
                text: root.text
                color: root.color
                font: root.font
                horizontalAlignment: Qt.AlignHCenter
                verticalAlignment: Qt.AlignVCenter
                visible: text.length > 0

                Behavior on color {
                    enabled: !Context.context || Context.onTop
                    ColorAnimation {
                        duration: Style.animationDuration("button", 100)
                    }
                }
            }

            Layout.alignment: Qt.AlignHCenter
        }
    }

    background: Rectangle {
        id: background
        color: root.Style.background.color
        border.color: root.Style.border.color
        border.width: root.Style.border.width
        radius: root.Style.border.radius

        Behavior on color {
            enabled: !Context.context || Context.onTop
            ColorAnimation {
                duration: Style.animationDuration("button", 100)
            }
        }
    }

    MouseArea {
        id: mouse
        anchors.fill: parent

        onClicked: () => {
            root.clicked()
            if (root.action !== void 0)
                PluginManager.async(root.action)
        }
    }

    Component.onCompleted: () => {
        if (Context.context)
            Context.addControlledAction(this)
    }
}
