import QtQml.Base
import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core

/**
 * @brief Таймер для кнопки
 *
 * @param seconds таймаут в секундах
 *
 * @signal timeout() вызывается по истечении таймаута
 *
 * @function run() запустить таймер
 * @function cancel() остановить таймер без сигнала @p timeout()
 */
RowLayout {
    id: root
    anchors {
        right: parent.right
        verticalCenter: parent.verticalCenter
    }
    spacing: Style.parameter("geometry.actionButtonTimer.spacing", 20)

    property alias seconds: timer.seconds
    property alias secondsLeft: timer.left
    property alias running: timer.running
    property alias icon: icon.source
    property alias label: leftLabel
    property bool show: secondsLeft > 1

    signal timeout()

    function run() {
        timer.left = seconds
    }

    function cancel() {
        timer.left = 0
    }

    opacity: show ? 1 : 0

    Behavior on opacity {
        NumberAnimation {
            easing.type: Easing.InExpo
            duration: Math.min(1000, Style.animationDuration("button.timer", 500))
        }
    }

    Timer {
        id: timer
        property int seconds: 10
        property int left: 0

        interval: 1000
        running: left > 0

        onTriggered: () => {
            if (!--left)
                root.timeout()
        }
    }

    SvgImage {
        id: icon
        source: Style.parameter("icon.timer")

        Layout.preferredHeight: Style.parameter("geometry.actionButtonTimer.iconSize", 50)
        Layout.preferredWidth: Style.parameter("geometry.actionButtonTimer.iconSize", 50)
    }

    SLabel { id: leftLabel; text: timer.left }

    Space { width: Style.parameter("geometry.actionButtonTimer.rightSpace", 40) }
}
