import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n

import "../check"

/*
 * @brief Контейнер для отображения корзины, списка покупок, кнопки добавления пакета и т. д.
 */
SGroupBox {
    id: mainBox
    leftPadding: 30
    rightPadding: leftPadding
    topPadding: 30
    bottomPadding: 0

    CheckModel { id: checkModel; onChanged: () => checkItems.invalidate() }
    property FilterModel checkItems: FilterModel {
        id: checkItems
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position || pos.type == CheckTypes.ItemType.Coupon
    }

    contentItem: Item {
        Control {
            objectName: "mainBoxPlaceholder"
            anchors.fill: parent
            topPadding: 60
            bottomPadding: 90
            visible: checkItems.count === 0
            contentItem: ColumnLayout {
                spacing: 40

                SvgImage {
                    objectName: "mainBoxBasketImage"
                    source: Style.parameter("icon.forming.emptyBasket")
                    Layout.preferredWidth: 250
                    Layout.preferredHeight: 250
                    Layout.alignment: Qt.AlignHCenter | Qt.AlignBottom
                }

                SLabel {
                    Style.class: "formingEmptyBasketTitle"
                    Tr { code: "formingEmptyBasketTitle" }
                    horizontalAlignment: Qt.AlignHCenter
                    Layout.alignment: Qt.AlignHCenter
                }

                SLabel {
                    Style.class: "formingEmptyBasketDetails"
                    Tr { code: "formingEmptyBasketDetails" }
                    horizontalAlignment: Qt.AlignHCenter
                    Layout.alignment: Qt.AlignHCenter
                }
            }
        }

        Item {
            anchors.fill: parent
            visible: checkItems.count > 0

            ColumnLayout {
                objectName: "basketLayout"
                anchors.fill: parent
                spacing: 30

                SLabel {
                    Style.class: "formingBasket"
                    Tr { code: "formingBasket" }
                    Layout.preferredHeight: contentHeight
                    Layout.preferredWidth: contentWidth
                }

                PositionList {
                    objectName: "positionsList"
                    property bool onlyHeft: Config.getBool("WeightControl:heft") && Config.getBool("WeightControl:onlyHeft")
                    forbidReduce: PluginManager.isPluginLoaded("WeightControl") && !onlyHeft
                    model: checkItems
                    edit: true
                    backgroundColor: mainBox.background.color
                    Layout.fillHeight: true
                    Layout.fillWidth: true

                    Rectangle {
                        color: Style.color("graySoft")
                        height: 1
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.top: parent.top
                    }
                }

                ActionButton {
                    objectName: "basketAddBagButton"
                    Style.class: "outlined"
                    Tr { code: "formingAddBag" }
                    icon: Style.parameter("icon.forming.addBag")
                    action: "CHECK_ADDBAG"

                    background: Rectangle {
                        color: "transparent"
                    }

                    Rectangle {
                        anchors.left: parent.left
                        anchors.right: parent.right
                        anchors.top: parent.top
                        color: Style.color("grayBorder")
                        height: 1
                    }

                    Layout.fillWidth: true
                    Layout.preferredHeight: 105
                }
            }
        }
    }
}
