import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Core

/**
 * @brief Карточка товара для диалогов
 *
 * @param name название товара
 * @param barcode штрих-код товара
 * @param image картинка товара
 * @param price цена товара
 */
GridLayout {
    id: root
    objectName: "goodsCardLayout"

    property bool vertical: true
    flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
    rowSpacing: 40
    columnSpacing: 40

    property bool hidePrice: false
    property var product: null
    property var name: product ? product.name : null
    property var barcode: product ? product.barcode : ""
    property var image: product ? product.image : null
    property var price: product ? product.price : null
    property alias labelName: labelName.type
    property alias labelBarcode: labelBarcode.type
    property alias moneyPrice: moneyPrice.type

    Item {
        objectName: "goodsCardImage"
        Layout.alignment: Qt.AlignHCenter
        height: 300
        Layout.fillWidth: true
        visible: !!root.image
        SvgImage {
            anchors.fill: parent
            source: root.image
        }
    }

    ColumnLayout {
        objectName: "goodsCardInfoLayout"

        RowLayout {
            Row {
                visible: root.barcode.length > 0
                spacing: 4
                SvgImage {
                    id: bcodeIcon
                    objectName: "goodsCardBcodeIcon"
                    source: Style.parameter("icon.barcode")
                }
                SLabel {
                    id: labelBarcode
                    property string type
                    Style.class: type
                    anchors.verticalCenter: parent.verticalCenter
                    text: root.barcode
                    verticalAlignment: Text.AlignVCenter
                    elide: Text.ElideRight
                }
                Layout.fillWidth: true
            }

            // TODO: Отображение оригинальной цены без скидки
            // Money {
            //     id: moneyDiscount
            //     visible: root.discount && !root.discount.zero
            //     property string type
            //     Style.class: type
            //     discount: true
            //     money: root.discount
            //     Layout.minimumWidth: implicitWidth
            // }

            Layout.fillWidth: true
        }

        GridLayout {
            id: namePriceRow
            objectName: "goodsCardNamePriceLayout"
            rows: 1
            columns: 2

            SLabel {
                id: labelName
                objectName: "goodsCardNameLabel"
                property string type
                Style.class: type
                text: root.name
                elide: Text.ElideRight
                wrapMode: Text.WordWrap
                maximumLineCount: root.vertical ? 1 : 2

                Layout.fillWidth: true
            }

            SMoney {
                id: moneyPrice
                property string type
                Style.class: type
                money: root.price
                visible: !root.hidePrice
                Layout.minimumWidth: implicitWidth
                Layout.alignment: Qt.AlignBottom
            }

            Layout.fillWidth: true
        }
    }
}
