import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import Check
import Core
import I18n

ColumnLayout {
    id: root
    objectName: "controls"

    spacing: 40

    property alias kbdInput: kbdInput
    property alias inputField: inputField
    property alias buttonsLayout: buttonsLayout
    property alias okButton: okButton
    property alias cancelButton: cancelButton

    // параметры
    property bool useDigits: true
    property string inputFieldClass: "inputField"
    property var okButtonTr: null
    property var cancelButtonTr: null

    ColumnLayout {
        id: kbdInput
        objectName: "keyboardInput"
        spacing: 40

        SGroupBox {
            id: inputFieldGroupBox
            objectName: "inputFieldGroupBox"
            Style.class: root.inputFieldClass

            contentItem: FocusScope {
                focus: true
                implicitHeight: inputField.implicitHeight

                STextEdit {
                    id: inputField
                    objectName: "inputField"
                    anchors.fill: parent
                    Style.class: "inputControls"

                    inputMethodHints: root.useDigits ? Qt.ImhDigitsOnly : 0
                    echoMode: TextInput.Normal
                    focus: true
                    clip: true

                    Component.onCompleted: () => this.forceActiveFocus()
                }
            }

            Layout.fillWidth: true
        }

        InlineKeyboard {
            objectName: "inlineKeyboard"
            Layout.fillWidth: true
            Layout.preferredHeight: 350
            layoutType: root.useDigits ? "digits" : "main"
        }
    }

    GridLayout {
        id: buttonsLayout
        objectName: "controlButtonsLayout"
        Layout.fillWidth: true
        property bool vertical: true
        flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
        layoutDirection: vertical ? Qt.LeftToRight : Qt.RightToLeft

        rowSpacing: 15
        columnSpacing: 15

        ActionButton {
            id: okButton
            objectName: "okButton"
            implicitWidth: 1

            Tr { tr: root.okButtonTr; fallback: "inputOk" }

            Layout.fillWidth: true
            Layout.preferredHeight: 105
        }
        ActionButton {
            id: cancelButton
            objectName: "cancelButton"
            Style.class: "outlined"
            icon: Style.parameter("icon.input.cancel")
            implicitWidth: 1

            property Tr cancelButtonTr

            Tr { tr: root.cancelButtonTr; fallback: "inputCancel" }

            Layout.fillWidth: true
            Layout.preferredHeight: 105
        }
    }

    Layout.fillWidth: true
    Layout.fillHeight: true
}
