import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import Check
import Core
import I18n

GridLayout {
    id: root
    property alias model: cards
    property alias inputCardButton: inputCardButton
    property alias inputCouponButton: inputCouponButton
    property string animationStyleSection: ""

    property string scanCardTrCode: "loyaltyScanLoyaltyCard"
    property string cardBalanceTrCode: "loyaltyCardBalance"
    property string inputCouponTrCode: "loyaltyInputCoupon"

    property bool vertical: false
    flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight

    CheckModel {
        id: checkModel
        onChanged: () => cardItem.updateCard()
    }
    FilterModel {
        id: cards
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Card

        onLayoutChanged: () => cardItem.updateCard()
    }

    Layout.fillWidth: true
    rowSpacing: 15
    columnSpacing: 15

    ActionButton {
        id: inputCardButton
        objectName: "inputCardButton"
        Style.class: "ActionButton"
        action: "CHECK_INPUTCARD"

        ColumnLayout {
            id: addButton
            opacity: inputCardButton.contentItem == this
            visible: inputCardButton.contentItem == this

            SLabel {
                color: inputCardButton.color
                font: inputCardButton.font

                Tr { code: scanCardTrCode }

                Layout.alignment: Qt.AlignHCenter
                horizontalAlignment: Qt.AlignHCenter
                Layout.fillWidth: true
                wrapMode: Text.WordWrap
                maximumLineCount: 2
            }

            Behavior on opacity {
                OpacityAnimator { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 500) }
            }
        }

        GridLayout {
            id: cardItem
            objectName: "loyaltyButtonsCardItemLayout"
            anchors.fill: parent

            flow: vertical ? GridLayout.TopToBottom : GridLayout.LeftToRight
            opacity: inputCardButton.contentItem == this
            visible: inputCardButton.contentItem == this

            // TODO: Устанавливать значение в зависимости от наличия встроенной рекламы
            property bool vertical: false
            property var cardIndex: cards.index(0, 0)
            property string cardName: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Name) : ""
            property string cardBalance: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.Balance).str : ""
            property var hasBalance: cardIndex && cardIndex.valid ? cards.data(cardIndex, CheckModel.HasBalance) : false
            function updateCard() {
                this.cardIndex = cards.index(0, 0)
            }

            property int leftMarginParam: 30
            property int rightMarginParam: 30
            property int topMarginParam: 20
            property int bottomMarginParam: 20

            RowLayout {
                objectName: "loyaltyButtonsCardLabelLayout"
                spacing: 20

                SLabel {
                    color: inputCardButton.color
                    font: inputCardButton.font
                    text: cardItem.cardName

                    elide: Text.ElideRight
                    Layout.fillWidth: true
                }
                Control {
                    visible: cards.count > 1
                    leftPadding: 8
                    rightPadding: 8

                    contentItem: SLabel {
                        color: inputCardButton.background.color
                        font: inputCardButton.font
                        text: "+" + (cards.count - 1)
                    }

                    background: Rectangle {
                        color: inputCardButton.color
                        radius: height / 2
                    }
                }

                Layout.leftMargin: parent.leftMarginParam
                Layout.rightMargin: cardItem.hasBalance && !parent.vertical ? 0 : parent.rightMarginParam
                Layout.topMargin: parent.vertical && !cardItem.hasBalance ? 0 : parent.topMarginParam
                Layout.bottomMargin: parent.vertical ? 0 : parent.vertical && !cardItem.hasBalance ? 0 : parent.bottomMarginParam
            }

            SLabel {
                id: balanceLabel
                color: inputCardButton.color
                font: inputCardButton.font
                visible: cardItem.hasBalance

                Tr { code: cardBalanceTrCode; args: [ cardItem.cardBalance ] }

                Layout.alignment: parent.vertical ? Qt.AlignLeft : Qt.AlignRight
                Layout.leftMargin: parent.leftMarginParam
                Layout.topMargin: parent.vertical ? 10 : parent.topMarginParam
                Layout.rightMargin: parent.rightMarginParam
                Layout.bottomMargin: parent.bottomMarginParam
            }

            Behavior on opacity {
                OpacityAnimator { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 500) }
            }

            Component.onCompleted: () => updateCard()
        }

        contentItem: cards.count === 0 ? addButton : cardItem

        implicitWidth: 2
        Layout.fillWidth: true
        Layout.minimumHeight: 80

        Behavior on height {
            NumberAnimation { duration: Style.animationDuration("transition" + animationStyleSection + ".cardInput", 100) }
        }
    }

    ActionButton {
        id: inputCouponButton
        objectName: "inputCouponButton"
        Style.class: "ActionButton"
        action: "CHECK_INPUTCOUPON"
        visible: false

        Tr { code: inputCouponTrCode }

        implicitWidth: 1
        Layout.fillWidth: true
        Layout.minimumHeight: 80
    }
}
