import QtQuick
import QtQuick.Shapes
import QtQuick.Controls
import QtQuick.Layouts

import Core

/**
 * @brief Виджет отображения денег (цена или стоимость позиции)
 *
 * @param money деньги типа @p Core::Money
 * @param discount является ценой без скидки (будет зачеркнуто и раскрасится в красный цвет)
 */
Item {
    id: root

    Style.class: "price"

    property bool discount
    property var money
    property color backgroundColor
    property color color: discount ? Style.color("redSoft") : Style.color("black")
    property color styleColor: label.Style.text.color
    property string prefix

    implicitWidth: label.contentWidth
    implicitHeight: label.contentHeight

    onMoneyChanged: () => label.updateText()
    Component.onCompleted: () => label.updateText()

    SLabel {
        id: label
        Style.class: root.Style.class
        color: root.color
        textFormat: Label.RichText
        verticalAlignment: SLabel.AlignBottom

        function updateText()  {
            if (!money) {
                this.text = prefix + "0.<small>00</small>"
                return
            }
            this.text = prefix + Money.format(money)
        }
    }

    Shape {
        anchors.fill: parent
        visible: root.discount

        ShapePath {
            strokeColor: root.backgroundColor
            strokeWidth: root.height * 0.10
            startX: 0
            startY: root.height * 0.85

            PathLine { x: root.width; y: root.height * 0.35 }
        }

        ShapePath {
            strokeColor: root.color
            strokeWidth: root.height * 0.08
            startX: 0
            startY: root.height * 0.80

            PathLine { x: root.width; y: root.height * 0.30 }
        }
    }
}
