import QtQuick
import QtQuick.Templates as T
import QtQuick.Controls.impl

import Core

/**
 * @brief Виджет тумблера
 * @param flow порядок отображения тумблера и текста
 */
T.Switch {
    id: control
    Style.type: "Switch"

    implicitWidth: indicator.implicitWidth + spacing + label.implicitWidth - label.leftPadding - label.rightPadding + leftPadding + rightPadding
    implicitHeight: Math.max(indicator.implicitHeight, label.implicitHeight) + topPadding + bottomPadding

    padding: 0
    spacing: 16
    down: false // выключаем свойство, чтобы не обрабатывались стили при нажатии (пока считаем, что это не требуется)

    property int flow: Qt.LeftToRight

    indicator: Rectangle {
        id: indicator
        y: (parent.implicitHeight - height) / 2
        x: flow == Qt.RightToLeft ? control.leftPadding + label.implicitWidth - label.rightPadding + control.spacing : control.leftPadding
        implicitWidth: control.Style.content.width
        implicitHeight: control.Style.content.height
        radius: control.Style.content.radius
        color: control.Style.content.color

        Rectangle {
            x: control.checked ? parent.width - width - 6 : 6
            y: (parent.height - height) / 2
            width: control.Style.indicator.width
            height: control.Style.indicator.height
            radius: control.Style.indicator.radius
            color: control.Style.indicator.color

            Behavior on x {
                SmoothedAnimation {
                    duration: Style.animationDuration("switch", 200)
                }
            }
        }
        Behavior on color {
            ColorAnimation {
                duration: Style.animationDuration("switch", 100)
            }
        }
    }

    contentItem: CheckLabel {
        id: label
        y: (parent.implicitHeight - height) / 2
        leftPadding: flow == Qt.LeftToRight ? control.indicator.width + control.spacing : 0
        rightPadding: flow == Qt.RightToLeft ? control.indicator.width + control.spacing : 0

        text: control.text
        font: control.Style.text.font
        color: control.Style.text.color
    }

    background: Rectangle {
        color: control.Style.background.color
        radius: control.Style.border.radius
    }
}
