import QtQuick
import QtQuick.Effects
import QtQuick.Particles
import QtQuick.Shapes

import Core

/*
 * @brief "Улыбка" на заднем фоне формы авторизации и приветствия
 */
Item {
    id: root

    property real multiplier: 1
    property color color: Style.color("welcomeBackground")
    property alias shadowColor: shadow.color
    property alias footerColor: footer.color
    property alias footerImage: image.source
    readonly property real bottomPadding: Style.parameter("geometry.smile.bottomPadding")

    Rectangle {
        id: footer

        anchors.fill: parent
        z: 1

        color: Style.color("welcomeFooterBackground")
        height: image.implicitHeight

        SvgImage {
            id: image
            anchors.bottom: parent.bottom
            anchors.horizontalCenter: parent.horizontalCenter

            source: Style.parameter("image.welcomeFooter")
        }
    }

    Shape {
        id: circle

        layer.enabled: root.multiplier == 1
        layer.samples: 4

        readonly property real originalHeight: 1644
        anchors.verticalCenter: root.bottom
        anchors.verticalCenterOffset: -root.bottomPadding - originalHeight / 2
        anchors.horizontalCenter: root.horizontalCenter

        z: 3

        width: Style.parameter("geometry.smile.width") * Math.pow(root.multiplier, 1.5)
        height: originalHeight * root.multiplier

        ShapePath {
            id: path
            fillColor: root.color
            startX: 0; startY: 0
            PathLine { x: 0; y: circle.height / 2 }
            PathArc {
                x: circle.width; y: circle.height / 2
                radiusX: circle.width / 2; radiusY: circle.height / 2
                direction: PathArc.Counterclockwise
            }
            PathLine { x: circle.width; y: 0 }
        }
    }

    MultiEffect {
        id: shadow
        property color color: Style.color("welcomeShadow")

        anchors.fill: circle
        z: 2

        source: circle
        shadowColor: color
        shadowVerticalOffset: 50
        blurMax: 64
        blurMultiplier: 2
        paddingRect: Qt.rect(0, 0, 0, 50)
        shadowEnabled: Style.parameter("shadows") === "true"
    }
}
