import QtQuick
import QtQml.Models
import QtQuick.Controls
import QtQuick.Layouts

import I18n
import Core

/**
 * @brief Список с циклическим отображением
 *
 * @param model модель элементов для отображения
 * @param delegate вид элемента
 * @param interactive можно ли скролить руками
 * @param offset текущий отступ от начала виджета до первого элемента
 *               при значении 1 - отсутп равен размеру элемента
 * @param flicking [readonly] пользователь сейчас скролит список
 * @param count [readonly] количество элементов
 * @param pathItemCount количество отображаемых элементов на пути
 * @param orientation направление списка. По умолчанию Speener.Horizontal
 *                    возможные значения: Speener.Horizontal, Speener.Vertical
 * @param path путь. Обычно подставляется в зависимости от @p orientation, можно переопределить
 * @param contentItemWidth, @param contentItemHeight ширина и высота отображаемых элементов
 *
 * @see PathView
 */
Control {
    id: root
    clip: true

    enum Orientation {
        Horizontal,
        Vertical
    }

    property alias model: pathView.model
    property alias delegate: pathView.delegate
    property alias interactive: pathView.interactive
    property alias offset: pathView.offset
    property alias flicking: pathView.flicking
    property alias count: pathView.count
    property alias pathItemCount: pathView.pathItemCount
    property alias preferredHighlightBegin: pathView.preferredHighlightBegin
    property alias preferredHighlightEnd: pathView.preferredHighlightEnd
    property alias currentIndex: pathView.currentIndex
    property int orientation: Speener.Orientation.Horizontal
    property Path path: orientation == 0 ? pathHorizontal : pathVertical
    property real contentItemWidth: 200
    property real contentItemHeight: 200

    QtObject {
        id: computed
        property real sumSpacing: pathView.pathItemCount > 0 ? root.spacing * (pathView.pathItemCount - 1) : 0
        property real fullWidth: contentItemWidth * pathView.pathItemCount + sumSpacing
        property real fullHeight: contentItemHeight * pathView.pathItemCount + sumSpacing
    }

    Path {
        id: pathVertical
        startX: pathView.width / 2; startY: contentItemHeight / 2 - 1

        PathLine {
            x: root.width / 2
            y: computed.fullHeight + contentItemHeight / 2
        }
    }

    Path {
        id: pathHorizontal
        startX: contentItemWidth / 2 - 1; startY: root.height / 2

        PathLine {
            x: computed.fullWidth + contentItemWidth / 2
            y: root.height / 2
        }
    }

    PathView {
        id: pathView
        anchors.fill: parent
        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5

        path: root.path
    }
}
