import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

/**
 * @brief Вид для древовидной модели
 *
 * @param model модель
 * @param delegate делегат
 *
 * @param popEnter       -+
 * @param popExit         |
 * @param pushEnter       | Анимации переходов
 * @param pushExit        |
 * @param replaceEnter    |
 * @param replaceExit    -+
 *
 * @prop currentItem текущий элемент
 * @prop depth глубина стека
 *
 * @signal beforePush(oldIndex)
 * @signal afterPush(newIndex)
 * @signal beforePop(oldIndex)
 * @signal afterPop(newIndex)
 *
 * @function push(index) Перейти глубже в @p index
 * @function pop() Вернуться на уровень выше
 */
Control {
    id: root
    property var model
    property Component delegate: Rectangle {}

    property alias currentItem: stack.currentItem
    property alias depth: stack.depth

    property alias popEnter: stack.popEnter
    property alias popExit: stack.popExit
    property alias pushEnter: stack.pushEnter
    property alias pushExit: stack.pushExit
    property alias replaceEnter: stack.replaceEnter
    property alias replaceExit: stack.replaceExit

    signal beforePush(oldIndex: var)
    signal afterPush(newIndex: var)
    signal beforePop(oldIndex: var)
    signal afterPop(newIndex: var)

    StackView {
        id: stack
        anchors.fill: parent
    }

    function push(index) {
        if (currentItem && currentItem.index === index)
            return;

        beforePush(currentItem ? currentItem.index : null)
        stack.push(root.delegate, { index: index, model: root.model })
        afterPush(index)
    }

    function pop() {
        if (depth <= 1)
            return;

        beforePop(currentItem.index)
        stack.pop()
        afterPop(currentItem.index)
    }

    Component.onCompleted: () => {
        root.push(model.rootIndex())
    }
}
