import QtQuick
import QtQuick.Controls

import Core

/**
 * @brief Анимация формы оплаты банковской картой
 */
SvgImage {
    source: Style.parameter("image.paymentTerminal")
    SvgImage {
        id: success
        property real baseDuration: Style.animationDuration("bankCard", 600)
        x: 140; y: 66
        width: 60; height: 60
        source: Style.parameter("image.paymentCardSuccess")
        state: timer.currentState
        states: [
            State {
                name: "start"
                PropertyChanges { target: success; opacity: 0; scale: 0 }
            },
            State {
                name: "finish"
                PropertyChanges { target: success; opacity: 1; scale: 1 }
            }
        ]
        transitions: [
            Transition {
                from: "start"; to: "finish"
                NumberAnimation {
                    property: "scale"; easing.type: Easing.InQuad; duration: success.baseDuration
                }
                NumberAnimation { property: "opacity"; duration: success.baseDuration }
            },
            Transition {
                from: "finish"; to: "start"
                NumberAnimation {
                    property: "scale"; easing.type: Easing.OutQuad; duration: success.baseDuration
                }
                NumberAnimation { property: "opacity"; duration: success.baseDuration }
            }
        ]
    }
    SvgImage {
        id: hand
        property real baseVelocity: Style.animationVelocity("bankCard", 200)
        source: Style.parameter("image.paymentHand")
        state: timer.currentState
        width: 278; height: 253
        states: [
            State {
                name: "start"
                PropertyChanges { target: hand; y: 185; x: 145 }
            },
            State {
                name: "finish"
                PropertyChanges { target: hand; y: 100; x: 230; rotation: 21 }
            }
        ]
        transitions: Transition {
            SmoothedAnimation { properties: "y"; velocity: hand.baseVelocity }
            SmoothedAnimation { properties: "x"; velocity: hand.baseVelocity }
            SmoothedAnimation { properties: "rotation"; velocity: hand.baseVelocity * 0.25 }
        }
    }
    Timer {
        id: timer
        property string currentState: "start"
        interval: Style.animationDuration("bankCard", 3000)
        running: true
        triggeredOnStart: true
        repeat: true
        onTriggered: {
            if (currentState == "start")
                currentState = "finish"
            else
                currentState = "start"
        }
    }
}
