import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

BaseForm {
    id: root
    Style.class: "formingForm"

    Context.context {
        inputSources: InputSources.All | InputSources.Rfid
        logoActionInfo: true
    }

    focusPolicy: Qt.ClickFocus

    CheckModel {
        id: checkModel
        onChanged: () => positions.invalidate()
    }
    FilterModel {
        id: positions
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
    }

    RowLayout {
        anchors.fill: parent
        spacing: 20

        ColumnLayout {
            Layout.fillWidth: true
            Layout.fillHeight: true
            spacing: 24

            BasketBox {
                id: mainBox
                objectName: "mainBox"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            RowLayout {
                objectName: "formingTotalLayout"
                spacing: 24

                SLabel {
                    Style.class: "formingTotal"
                    Tr { code: "formingTotal" }
                    Layout.fillWidth: true
                }

                SMoney {
                    Style.class: "formingTotalSumNoDisc"
                    visible: Check.total !== Check.totalNoDisc
                    discount: true
                    money: Check.totalNoDisc
                    color: Style.color("grayDark")
                    backgroundColor: Style.color("background")
                }

                SMoney {
                    Style.class: "formingTotalSum"
                    money: Check.total
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 36
                Layout.bottomMargin: 10
            }
        }

        ColumnLayout {
            objectName: "buttonsLayout"
            spacing: 10
            Layout.fillHeight: true
            Layout.maximumWidth: 235

            LoyaltyButtons {
                vertical: true
                objectName: "loyaltyButtons"
                scanCardTrCode: "formingScanLoyaltyCard"
                cardBalanceTrCode: "formingCardBalance"
                inputCouponTrCode: "formingInputCoupon"

                inputCouponButton {
                    Style.class: "formingInputCoupon"
                    visible: Config.getBool("Scong:showInputCouponInForming")
                }

                animationStyleSection: ".forming"
                inputCardButton.Style.class: "formingInputCard"
            }

            ActionButton {
                Style.class: "formingFlatButton"
                Layout.preferredHeight: 60
                Layout.fillWidth: true
                Tr { code: "formingPickList" }

                action: "PICKLIST_SHOW"
            }
            ActionButton {
                Style.class: "formingFlatButton"
                Layout.preferredHeight: 60
                Tr { code: "formingChangeNextQuantity" }
                icon: Style.parameter("icon.forming.inputQuantity")
                action: "CHECK_CHANGENEXTQUANTITY"
                Layout.fillWidth: true
            }
            ActionButton {
                Style.class: "formingFlatButton"
                Layout.preferredHeight: 60
                Tr { code: "formingInput" }
                icon: Style.parameter("icon.forming.input")
                action: "CHECK_MANUALINPUT"
                Layout.fillWidth: true
            }

            Item {
                Layout.fillHeight: true
                Layout.preferredHeight: 0
                Layout.minimumHeight: 0
                implicitHeight: 0
            }

            AgeVerifyNotificationBox {
                topPadding: 16
                rightPadding: 16
                bottomPadding: 16
                leftPadding: 16

                ageVerifyLabel {
                    topPadding: 5
                    bottomPadding: 5
                    leftPadding: 5
                    rightPadding: 5
                }
                ageVerifyLayout {
                    rows: 2
                    columns: 1
                    rowSpacing: 4
                }
            }

            ActionButton {
                objectName: "subtotalButton"
                id: subtotalButton
                property bool back: Check.status === CheckTypes.Status.None
                Style.class: !back ? "formingSubtotal" : "formingBack"
                enabled: back || (positions.count > 0)
                icon: !back ? Style.parameter("icon.forming.subtotal") : Style.parameter("icon.forming.back")
                Tr { code: !subtotalButton.back ? "formingSubtotal" : "formingBack" }
                action: !back ? "CHECK_SUBTOTAL" : "CHECK_BACKTOWELCOME"
                Layout.fillWidth: true
                Layout.preferredHeight: 70
            }
        }
    }

    pushEnter: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 0
                duration: Style.animationDuration("transition.forming", 300)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 1
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.forming", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "opacity"; to: 1; duration: 0 }
    }
}
