import QtQuick
import QtQuick.Controls

import Core

import "../widgets"

SvgImage {
    id: scales
    source: Style.parameter("image.weightControl.scales")
    implicitWidth: implicitWidth * baseScale
    implicitHeight: implicitHeight * baseScale
    property real baseScale: Style.parameter("geometry.weightControl.removingImage.scale", 1)
    property real baseVelocity: Style.animationVelocity("weightControl.removing", 100)
    SvgImage {
        id: arrow
        scale: scales.baseScale
        anchors.horizontalCenter: parent.horizontalCenter
        source: Style.parameter("image.weightControl.arrowUp")
        state: timer.currentState
        states: [
            State { name: "start"; PropertyChanges { target: arrow; y: -170 }},
            State { name: "finish"; PropertyChanges { target: arrow; y: -65 }}
        ]
        Behavior on y { SmoothedAnimation { velocity: scales.baseVelocity }}
    }
    SvgImage {
        id: hand
        x: -240
        scale: scales.baseScale
        source: Style.parameter("image.weightControl.hand")
        state: timer.currentState
        states: [
            State { name: "start"; PropertyChanges { target: hand; rotation: -30; y: -245 }},
            State { name: "finish"; PropertyChanges { target: hand; rotation: 0; y: -175 }}
        ]
        transitions: Transition {
             SmoothedAnimation { properties: "rotation"; velocity: scales.baseVelocity * 0.29 }
             SmoothedAnimation { properties: "y"; velocity: scales.baseVelocity * 0.74 }
        }
    }
    SvgImage {
        scale: scales.baseScale
        source: Style.parameter("image.weightControl.bag")
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: -93
    }
    Timer {
        id: timer
        property string currentState: "start"
        interval: Style.animationDuration("weightControl.removing", 2500)
        running: true
        triggeredOnStart: true
        repeat: true
        onTriggered: {
            if (currentState == "start")
                currentState = "finish"
            else
                currentState = "start"
        }
    }
}
