import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Check
import Core
import I18n
import PickList as PL

import "../core"
import "../picklist"
import "../widgets"

BaseForm {
    id: root
    Style.class: "formingForm"

    Context.context {
        inputSources: InputSources.All | InputSources.Rfid
        logoActionInfo: true
    }

    focusPolicy: Qt.ClickFocus

    CheckModel {
        id: checkModel
        onChanged: () => positions.invalidate()
    }
    FilterModel {
        id: positions
        sourceModel: checkModel
        filterFunction: (pos) => pos.type == CheckTypes.ItemType.Position
    }

    RowLayout {
        anchors.fill: parent
        spacing: 40

        ColumnLayout {
            Layout.fillWidth: true
            Layout.fillHeight: true
            spacing: 45

            BasketBox {
                id: mainBox
                objectName: "mainBox"
                Layout.fillWidth: true
                Layout.fillHeight: true
            }

            RowLayout {
                spacing: 40

                SLabel {
                    Style.class: "formingTotal"
                    Tr { code: "formingTotal" }
                    Layout.fillWidth: true
                }
                SMoney {
                    Style.class: "formingTotalSumNoDisc"
                    visible: Check.total !== Check.totalNoDisc
                    discount: true
                    money: Check.totalNoDisc
                    color: Style.color("grayDark")
                    backgroundColor: Style.color("background")
                }
                SMoney {
                    Style.class: "formingTotalSum"
                    money: Check.total
                }

                Layout.fillWidth: true
                Layout.preferredHeight: 48
            }
        }

        ColumnLayout {
            objectName: "buttonsLayout"
            spacing: 20
            Layout.fillHeight: true
            Layout.maximumWidth: 275

            LoyaltyButtons {
                vertical: true
                objectName: "loyaltyButtons"
                scanCardTrCode: "formingScanLoyaltyCard"
                cardBalanceTrCode: "formingCardBalance"
                inputCouponTrCode: "formingInputCoupon"

                inputCouponButton {
                    Style.class: "formingInputCoupon"
                    visible: Config.getBool("Scong:showInputCouponInForming")
                }

                animationStyleSection: ".forming"
                inputCardButton.Style.class: "formingInputCard"
            }

            ActionButton {
                Style.class: "formingPickListSearch"
                Layout.preferredHeight: 70
                Layout.fillWidth: true
                Tr { code: "formingPickList" }

                action: "PICKLIST_SHOW"
            }
            ActionButton {
                Style.class: "formingFlatButton"
                Layout.preferredHeight: 70
                Tr { code: "formingChangeNextQuantity" }
                icon: Style.parameter("icon.forming.inputQuantity")
                action: "CHECK_CHANGENEXTQUANTITY"
                Layout.fillWidth: true
            }
            ActionButton {
                Style.class: "formingFlatButton"
                Layout.preferredHeight: 70
                Tr { code: "formingInput" }
                icon: Style.parameter("icon.forming.input")
                action: "CHECK_MANUALINPUT"
                Layout.fillWidth: true
            }

            Item {
                Layout.fillHeight: true
                Layout.preferredHeight: 0
                Layout.minimumHeight: 0
                implicitHeight: 0
            }

            ColumnLayout {
                spacing: 35

                SGroupBox {
                    id: ageVerifyBox
                    Style.class: "formingAgeVerify"
                    padding: 20

                    opacity: Check.needAgeVerify && height === implicitHeight ? 1 : 0

                    contentItem: ColumnLayout {
                        spacing: 10

                        SGroupBox {
                            Style.class: "formingAgeVerifyLabel"
                            topPadding: 12
                            rightPadding: 12
                            bottomPadding: 12
                            leftPadding: 12

                            contentItem: SLabel {
                                Style.class: "formingAgeVerifyLabel"
                                text: "18+"
                            }

                            Layout.preferredWidth: implicitWidth
                            Layout.preferredHeight: implicitHeight
                        }

                        SLabel {
                            Style.class: "formingAgeVerifyDetails"
                            Tr { code: "formingAgeVerifyDetails" }
                            verticalAlignment: Qt.AlignVCenter
                            wrapMode: SLabel.WordWrap
                            lineHeight: 1.2

                            Layout.preferredHeight: contentHeight
                            Layout.fillWidth: true
                        }
                    }

                    Behavior on opacity {
                        NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.forming.ageVerify", 250) }
                    }

                    Behavior on Layout.preferredHeight {
                        NumberAnimation { easing.type: Easing.InOutQuad; duration: Style.animationDuration("transition.forming.ageVerify", 250) }
                    }

                    Layout.fillWidth: true
                    Layout.preferredHeight: Check.needAgeVerify || opacity > 0 ? implicitHeight : 0
                }

                ActionButton {
                    objectName: "subtotalButton"
                    id: subtotalButton
                    property bool back: Check.status === CheckTypes.Status.None
                    Style.class: !back ? "formingSubtotal" : "formingBack"
                    enabled: back || (positions.count > 0)
                    icon: !back ? Style.parameter("icon.forming.subtotal") : Style.parameter("icon.forming.back")
                    Tr { code: !subtotalButton.back ? "formingSubtotal" : "formingBack" }
                    action: !back ? "CHECK_SUBTOTAL" : "CHECK_BACKTOWELCOME"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 90
                }
            }
        }
    }

    pushEnter: Transition {
        SequentialAnimation {
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 0
                duration: Style.animationDuration("transition.forming", 300)
            }
            NumberAnimation {
                target: root; property: "opacity"
                from: 0; to: 1
                easing.type: Easing.InCubic
                duration: Style.animationDuration("transition.forming", 500)
            }
        }
    }

    popEnter: Transition {
        NumberAnimation { target: root; property: "opacity"; to: 1; duration: 0 }
    }
}
