import QtQuick
import QtQuick.Controls

import Core

import "../widgets"

Page {
    leftPadding: 0
    rightPadding: 0
    topPadding: 0
    bottomPadding: 0
    implicitWidth: 496 + leftPadding
    implicitHeight: 439
    background: null

    SvgImage {
        id: scale
        source: Style.parameter("image.weightControl.unstable.scales")
        implicitWidth: implicitWidth * baseScale
        implicitHeight: implicitHeight * baseScale
        property real baseScale: Style.parameter("geometry.weightControl.unstableImage.scale", 1)

        SvgImage {
            id: hand
            x: -143
            scale: scale.baseScale
            property real baseVelocity: Style.animationVelocity("weightControl.unstable", 160)
            state: timer.currentState
            source: Style.parameter("image.weightControl.unstable.hand")
            states: [
                State { name: "start"; PropertyChanges { target: hand; y: 58; rotation: 0 }},
                State { name: "finish"; PropertyChanges { target: hand; y: 109; rotation: 15 }}
            ]
            transitions: Transition {
                SmoothedAnimation { properties: "y"; velocity: hand.baseVelocity }
                SmoothedAnimation { properties: "rotation"; velocity: hand.baseVelocity * 0.3 }
            }
        }
        Timer {
            id: timer
            property string currentState: "start"
            interval: Style.animationDuration("weightControl.unstable", 3000)
            running: true
            triggeredOnStart: true
            repeat: true
            onTriggered: {
                if (currentState == "start")
                    currentState = "finish"
                else
                    currentState = "start"
            }
        }
    }

    property var dashes: [
        {
            begX: 32 - leftPadding,
            begY: height - 40,
            endX: -68 - leftPadding,
            rotation: 5
        },
        {
            begX: 32 - leftPadding,
            begY: height - 30,
            endX: -71 - leftPadding,
            rotation: -15
        },
        {
            begX: 27 - leftPadding,
            begY: height - 25,
            endX: -49 - leftPadding,
            rotation: -40
        },
        {
            begX: width - 140 - leftPadding,
            begY: height - 40,
            endX: width - 40 - leftPadding,
            rotation: -5
        },
        {
            begX: width - 140 - leftPadding,
            begY: height - 30,
            endX: width - 37 - leftPadding,
            rotation: 15
        },
        {
            begX: width - 135 - leftPadding,
            begY: height - 25,
            endX: width - 59 - leftPadding,
            rotation: 40
        }
    ]
    function getEndY(model) {
        var lambdaX = model.endX - model.begX
        const toRad = deg => (deg * Math.PI) / 180.0
        return model.begY + (lambdaX * Math.sin(toRad(model.rotation))) / Math.sin(toRad(90 - model.rotation))
    }
    Repeater {
        z: parent.z - 1
        model: dashes
        Rectangle {
            id: dash
            property real endY: getEndY(modelData)
            property real lambdaX: Math.abs(modelData.endX - modelData.begX)
            property real lambdaY: Math.abs(endY - modelData.begY)
            color: Style.color("redSoft")
            width: 48
            height: 4
            radius: 4
            z: parent.z - 1
            rotation: modelData.rotation
            state: timer.currentState
            states: [
                State { name: "start"; PropertyChanges { target: dash; x: modelData.begX; y: modelData.begY } },
                State { name: "finish"; PropertyChanges { target: dash; x: modelData.endX; y: endY } }
            ]
            transitions: Transition {
                SmoothedAnimation {
                    properties: "x"
                    velocity: hand.baseVelocity * 1.8 * (dash.lambdaX / 50)
                }
                SmoothedAnimation {
                    properties: "y"
                    velocity: hand.baseVelocity * 1.8 * (dash.lambdaY / 50)
                }
            }
        }
    }
}
